# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError

from typing_extensions import Annotated
from pydantic import Field, StrictInt, StrictStr

from typing import Optional

from OSCR_django_client.models.ladder_entries_list200_response import LadderEntriesList200Response
from OSCR_django_client.models.ladder_entry import LadderEntry

from OSCR_django_client.api_client import ApiClient
from OSCR_django_client.api_response import ApiResponse
from OSCR_django_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class LadderEntriesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def ladder_entries_list(self, player : Annotated[Optional[StrictStr], Field(description="player")] = None, ladder : Annotated[Optional[StrictStr], Field(description="ladder")] = None, ladder__name : Annotated[Optional[StrictStr], Field(description="ladder__name")] = None, ladder__difficulty : Annotated[Optional[StrictStr], Field(description="ladder__difficulty")] = None, data__name : Annotated[Optional[StrictStr], Field(description="data__name")] = None, data__is_player : Annotated[Optional[StrictStr], Field(description="data__is_player")] = None, data__total_damage__lt : Annotated[Optional[StrictStr], Field(description="data__total_damage__lt")] = None, data__total_damage__gt : Annotated[Optional[StrictStr], Field(description="data__total_damage__gt")] = None, data__total_damage__lte : Annotated[Optional[StrictStr], Field(description="data__total_damage__lte")] = None, data__total_damage__gte : Annotated[Optional[StrictStr], Field(description="data__total_damage__gte")] = None, data__total_damage : Annotated[Optional[StrictStr], Field(description="data__total_damage")] = None, data__total_attacks__lt : Annotated[Optional[StrictStr], Field(description="data__total_attacks__lt")] = None, data__total_attacks__gt : Annotated[Optional[StrictStr], Field(description="data__total_attacks__gt")] = None, data__total_attacks__lte : Annotated[Optional[StrictStr], Field(description="data__total_attacks__lte")] = None, data__total_attacks__gte : Annotated[Optional[StrictStr], Field(description="data__total_attacks__gte")] = None, data__total_attacks : Annotated[Optional[StrictStr], Field(description="data__total_attacks")] = None, data__total_hull_damage__lt : Annotated[Optional[StrictStr], Field(description="data__total_hull_damage__lt")] = None, data__total_hull_damage__gt : Annotated[Optional[StrictStr], Field(description="data__total_hull_damage__gt")] = None, data__total_hull_damage__lte : Annotated[Optional[StrictStr], Field(description="data__total_hull_damage__lte")] = None, data__total_hull_damage__gte : Annotated[Optional[StrictStr], Field(description="data__total_hull_damage__gte")] = None, data__total_hull_damage : Annotated[Optional[StrictStr], Field(description="data__total_hull_damage")] = None, data__total_shield_damage__lt : Annotated[Optional[StrictStr], Field(description="data__total_shield_damage__lt")] = None, data__total_shield_damage__gt : Annotated[Optional[StrictStr], Field(description="data__total_shield_damage__gt")] = None, data__total_shield_damage__lte : Annotated[Optional[StrictStr], Field(description="data__total_shield_damage__lte")] = None, data__total_shield_damage__gte : Annotated[Optional[StrictStr], Field(description="data__total_shield_damage__gte")] = None, data__total_shield_damage : Annotated[Optional[StrictStr], Field(description="data__total_shield_damage")] = None, data__total_heal_instances__lt : Annotated[Optional[StrictStr], Field(description="data__total_heal_instances__lt")] = None, data__total_heal_instances__gt : Annotated[Optional[StrictStr], Field(description="data__total_heal_instances__gt")] = None, data__total_heal_instances__lte : Annotated[Optional[StrictStr], Field(description="data__total_heal_instances__lte")] = None, data__total_heal_instances__gte : Annotated[Optional[StrictStr], Field(description="data__total_heal_instances__gte")] = None, data__total_heal_instances : Annotated[Optional[StrictStr], Field(description="data__total_heal_instances")] = None, data__total_crits__lt : Annotated[Optional[StrictStr], Field(description="data__total_crits__lt")] = None, data__total_crits__gt : Annotated[Optional[StrictStr], Field(description="data__total_crits__gt")] = None, data__total_crits__lte : Annotated[Optional[StrictStr], Field(description="data__total_crits__lte")] = None, data__total_crits__gte : Annotated[Optional[StrictStr], Field(description="data__total_crits__gte")] = None, data__total_crits : Annotated[Optional[StrictStr], Field(description="data__total_crits")] = None, data__total_heal_crits__lt : Annotated[Optional[StrictStr], Field(description="data__total_heal_crits__lt")] = None, data__total_heal_crits__gt : Annotated[Optional[StrictStr], Field(description="data__total_heal_crits__gt")] = None, data__total_heal_crits__lte : Annotated[Optional[StrictStr], Field(description="data__total_heal_crits__lte")] = None, data__total_heal_crits__gte : Annotated[Optional[StrictStr], Field(description="data__total_heal_crits__gte")] = None, data__total_heal_crits : Annotated[Optional[StrictStr], Field(description="data__total_heal_crits")] = None, data__total_heals__lt : Annotated[Optional[StrictStr], Field(description="data__total_heals__lt")] = None, data__total_heals__gt : Annotated[Optional[StrictStr], Field(description="data__total_heals__gt")] = None, data__total_heals__lte : Annotated[Optional[StrictStr], Field(description="data__total_heals__lte")] = None, data__total_heals__gte : Annotated[Optional[StrictStr], Field(description="data__total_heals__gte")] = None, data__total_heals : Annotated[Optional[StrictStr], Field(description="data__total_heals")] = None, data__total_damage_taken__lt : Annotated[Optional[StrictStr], Field(description="data__total_damage_taken__lt")] = None, data__total_damage_taken__gt : Annotated[Optional[StrictStr], Field(description="data__total_damage_taken__gt")] = None, data__total_damage_taken__lte : Annotated[Optional[StrictStr], Field(description="data__total_damage_taken__lte")] = None, data__total_damage_taken__gte : Annotated[Optional[StrictStr], Field(description="data__total_damage_taken__gte")] = None, data__total_damage_taken : Annotated[Optional[StrictStr], Field(description="data__total_damage_taken")] = None, data__total_attacks_taken__lt : Annotated[Optional[StrictStr], Field(description="data__total_attacks_taken__lt")] = None, data__total_attacks_taken__gt : Annotated[Optional[StrictStr], Field(description="data__total_attacks_taken__gt")] = None, data__total_attacks_taken__lte : Annotated[Optional[StrictStr], Field(description="data__total_attacks_taken__lte")] = None, data__total_attacks_taken__gte : Annotated[Optional[StrictStr], Field(description="data__total_attacks_taken__gte")] = None, data__total_attacks_taken : Annotated[Optional[StrictStr], Field(description="data__total_attacks_taken")] = None, data__deaths__lt : Annotated[Optional[StrictStr], Field(description="data__deaths__lt")] = None, data__deaths__gt : Annotated[Optional[StrictStr], Field(description="data__deaths__gt")] = None, data__deaths__lte : Annotated[Optional[StrictStr], Field(description="data__deaths__lte")] = None, data__deaths__gte : Annotated[Optional[StrictStr], Field(description="data__deaths__gte")] = None, data__deaths : Annotated[Optional[StrictStr], Field(description="data__deaths")] = None, data__max_one_hit__lt : Annotated[Optional[StrictStr], Field(description="data__max_one_hit__lt")] = None, data__max_one_hit__gt : Annotated[Optional[StrictStr], Field(description="data__max_one_hit__gt")] = None, data__max_one_hit__lte : Annotated[Optional[StrictStr], Field(description="data__max_one_hit__lte")] = None, data__max_one_hit__gte : Annotated[Optional[StrictStr], Field(description="data__max_one_hit__gte")] = None, data__max_one_hit : Annotated[Optional[StrictStr], Field(description="data__max_one_hit")] = None, data__max_one_hit_weapon : Annotated[Optional[StrictStr], Field(description="data__max_one_hit_weapon")] = None, data__max_one_heal__lt : Annotated[Optional[StrictStr], Field(description="data__max_one_heal__lt")] = None, data__max_one_heal__gt : Annotated[Optional[StrictStr], Field(description="data__max_one_heal__gt")] = None, data__max_one_heal__lte : Annotated[Optional[StrictStr], Field(description="data__max_one_heal__lte")] = None, data__max_one_heal__gte : Annotated[Optional[StrictStr], Field(description="data__max_one_heal__gte")] = None, data__max_one_heal : Annotated[Optional[StrictStr], Field(description="data__max_one_heal")] = None, data__max_one_heal_weapon : Annotated[Optional[StrictStr], Field(description="data__max_one_heal_weapon")] = None, data__dps__lt : Annotated[Optional[StrictStr], Field(description="data__dps__lt")] = None, data__dps__gt : Annotated[Optional[StrictStr], Field(description="data__dps__gt")] = None, data__dps__lte : Annotated[Optional[StrictStr], Field(description="data__dps__lte")] = None, data__dps__gte : Annotated[Optional[StrictStr], Field(description="data__dps__gte")] = None, data__dps : Annotated[Optional[StrictStr], Field(description="data__dps")] = None, data__crith__lt : Annotated[Optional[StrictStr], Field(description="data__crith__lt")] = None, data__crith__gt : Annotated[Optional[StrictStr], Field(description="data__crith__gt")] = None, data__crith__lte : Annotated[Optional[StrictStr], Field(description="data__crith__lte")] = None, data__crith__gte : Annotated[Optional[StrictStr], Field(description="data__crith__gte")] = None, data__crith : Annotated[Optional[StrictStr], Field(description="data__crith")] = None, data__heal_crith__lt : Annotated[Optional[StrictStr], Field(description="data__heal_crith__lt")] = None, data__heal_crith__gt : Annotated[Optional[StrictStr], Field(description="data__heal_crith__gt")] = None, data__heal_crith__lte : Annotated[Optional[StrictStr], Field(description="data__heal_crith__lte")] = None, data__heal_crith__gte : Annotated[Optional[StrictStr], Field(description="data__heal_crith__gte")] = None, data__heal_crith : Annotated[Optional[StrictStr], Field(description="data__heal_crith")] = None, data__start_time : Annotated[Optional[StrictStr], Field(description="data__start_time")] = None, data__total_time : Annotated[Optional[StrictStr], Field(description="data__total_time")] = None, data__flanks__lt : Annotated[Optional[StrictStr], Field(description="data__flanks__lt")] = None, data__flanks__gt : Annotated[Optional[StrictStr], Field(description="data__flanks__gt")] = None, data__flanks__lte : Annotated[Optional[StrictStr], Field(description="data__flanks__lte")] = None, data__flanks__gte : Annotated[Optional[StrictStr], Field(description="data__flanks__gte")] = None, data__flanks : Annotated[Optional[StrictStr], Field(description="data__flanks")] = None, data__misses__lt : Annotated[Optional[StrictStr], Field(description="data__misses__lt")] = None, data__misses__gt : Annotated[Optional[StrictStr], Field(description="data__misses__gt")] = None, data__misses__lte : Annotated[Optional[StrictStr], Field(description="data__misses__lte")] = None, data__misses__gte : Annotated[Optional[StrictStr], Field(description="data__misses__gte")] = None, data__misses : Annotated[Optional[StrictStr], Field(description="data__misses")] = None, data__kills__lt : Annotated[Optional[StrictStr], Field(description="data__kills__lt")] = None, data__kills__gt : Annotated[Optional[StrictStr], Field(description="data__kills__gt")] = None, data__kills__lte : Annotated[Optional[StrictStr], Field(description="data__kills__lte")] = None, data__kills__gte : Annotated[Optional[StrictStr], Field(description="data__kills__gte")] = None, data__kills : Annotated[Optional[StrictStr], Field(description="data__kills")] = None, data__runtime : Annotated[Optional[StrictStr], Field(description="data__runtime")] = None, data__end_time : Annotated[Optional[StrictStr], Field(description="data__end_time")] = None, data__accuracy__lt : Annotated[Optional[StrictStr], Field(description="data__accuracy__lt")] = None, data__accuracy__gt : Annotated[Optional[StrictStr], Field(description="data__accuracy__gt")] = None, data__accuracy__lte : Annotated[Optional[StrictStr], Field(description="data__accuracy__lte")] = None, data__accuracy__gte : Annotated[Optional[StrictStr], Field(description="data__accuracy__gte")] = None, data__accuracy : Annotated[Optional[StrictStr], Field(description="data__accuracy")] = None, data__resist__lt : Annotated[Optional[StrictStr], Field(description="data__resist__lt")] = None, data__resist__gt : Annotated[Optional[StrictStr], Field(description="data__resist__gt")] = None, data__resist__lte : Annotated[Optional[StrictStr], Field(description="data__resist__lte")] = None, data__resist__gte : Annotated[Optional[StrictStr], Field(description="data__resist__gte")] = None, data__resist : Annotated[Optional[StrictStr], Field(description="data__resist")] = None, data__hull_attacks__lt : Annotated[Optional[StrictStr], Field(description="data__hull_attacks__lt")] = None, data__hull_attacks__gt : Annotated[Optional[StrictStr], Field(description="data__hull_attacks__gt")] = None, data__hull_attacks__lte : Annotated[Optional[StrictStr], Field(description="data__hull_attacks__lte")] = None, data__hull_attacks__gte : Annotated[Optional[StrictStr], Field(description="data__hull_attacks__gte")] = None, data__hull_attacks : Annotated[Optional[StrictStr], Field(description="data__hull_attacks")] = None, data__final_resist__lt : Annotated[Optional[StrictStr], Field(description="data__final_resist__lt")] = None, data__final_resist__gt : Annotated[Optional[StrictStr], Field(description="data__final_resist__gt")] = None, data__final_resist__lte : Annotated[Optional[StrictStr], Field(description="data__final_resist__lte")] = None, data__final_resist__gte : Annotated[Optional[StrictStr], Field(description="data__final_resist__gte")] = None, data__final_resist : Annotated[Optional[StrictStr], Field(description="data__final_resist")] = None, data__percent_attacks__lt : Annotated[Optional[StrictStr], Field(description="data__percent_attacks__lt")] = None, data__percent_attacks__gt : Annotated[Optional[StrictStr], Field(description="data__percent_attacks__gt")] = None, data__percent_attacks__lte : Annotated[Optional[StrictStr], Field(description="data__percent_attacks__lte")] = None, data__percent_attacks__gte : Annotated[Optional[StrictStr], Field(description="data__percent_attacks__gte")] = None, data__percent_attacks : Annotated[Optional[StrictStr], Field(description="data__percent_attacks")] = None, data__percent_damage__lt : Annotated[Optional[StrictStr], Field(description="data__percent_damage__lt")] = None, data__percent_damage__gt : Annotated[Optional[StrictStr], Field(description="data__percent_damage__gt")] = None, data__percent_damage__lte : Annotated[Optional[StrictStr], Field(description="data__percent_damage__lte")] = None, data__percent_damage__gte : Annotated[Optional[StrictStr], Field(description="data__percent_damage__gte")] = None, data__percent_damage : Annotated[Optional[StrictStr], Field(description="data__percent_damage")] = None, data__percent_damage_taken__lt : Annotated[Optional[StrictStr], Field(description="data__percent_damage_taken__lt")] = None, data__percent_damage_taken__gt : Annotated[Optional[StrictStr], Field(description="data__percent_damage_taken__gt")] = None, data__percent_damage_taken__lte : Annotated[Optional[StrictStr], Field(description="data__percent_damage_taken__lte")] = None, data__percent_damage_taken__gte : Annotated[Optional[StrictStr], Field(description="data__percent_damage_taken__gte")] = None, data__percent_damage_taken : Annotated[Optional[StrictStr], Field(description="data__percent_damage_taken")] = None, data__percent_healed__lt : Annotated[Optional[StrictStr], Field(description="data__percent_healed__lt")] = None, data__percent_healed__gt : Annotated[Optional[StrictStr], Field(description="data__percent_healed__gt")] = None, data__percent_healed__lte : Annotated[Optional[StrictStr], Field(description="data__percent_healed__lte")] = None, data__percent_healed__gte : Annotated[Optional[StrictStr], Field(description="data__percent_healed__gte")] = None, data__percent_healed : Annotated[Optional[StrictStr], Field(description="data__percent_healed")] = None, data__attacks_per_minute__lt : Annotated[Optional[StrictStr], Field(description="data__attacks_per_minute__lt")] = None, data__attacks_per_minute__gt : Annotated[Optional[StrictStr], Field(description="data__attacks_per_minute__gt")] = None, data__attacks_per_minute__lte : Annotated[Optional[StrictStr], Field(description="data__attacks_per_minute__lte")] = None, data__attacks_per_minute__gte : Annotated[Optional[StrictStr], Field(description="data__attacks_per_minute__gte")] = None, data__attacks_per_minute : Annotated[Optional[StrictStr], Field(description="data__attacks_per_minute")] = None, data__hps__lt : Annotated[Optional[StrictStr], Field(description="data__hps__lt")] = None, data__hps__gt : Annotated[Optional[StrictStr], Field(description="data__hps__gt")] = None, data__hps__lte : Annotated[Optional[StrictStr], Field(description="data__hps__lte")] = None, data__hps__gte : Annotated[Optional[StrictStr], Field(description="data__hps__gte")] = None, data__hps : Annotated[Optional[StrictStr], Field(description="data__hps")] = None, ordering : Annotated[Optional[StrictStr], Field(description="Which field to use when ordering the results.")] = None, page : Annotated[Optional[StrictInt], Field(description="A page number within the paginated result set.")] = None, page_size : Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None, **kwargs) -> LadderEntriesList200Response:  # noqa: E501
        """ladder_entries_list  # noqa: E501

        LadderEntry API  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.ladder_entries_list(player, ladder, ladder__name, ladder__difficulty, data__name, data__is_player, data__total_damage__lt, data__total_damage__gt, data__total_damage__lte, data__total_damage__gte, data__total_damage, data__total_attacks__lt, data__total_attacks__gt, data__total_attacks__lte, data__total_attacks__gte, data__total_attacks, data__total_hull_damage__lt, data__total_hull_damage__gt, data__total_hull_damage__lte, data__total_hull_damage__gte, data__total_hull_damage, data__total_shield_damage__lt, data__total_shield_damage__gt, data__total_shield_damage__lte, data__total_shield_damage__gte, data__total_shield_damage, data__total_heal_instances__lt, data__total_heal_instances__gt, data__total_heal_instances__lte, data__total_heal_instances__gte, data__total_heal_instances, data__total_crits__lt, data__total_crits__gt, data__total_crits__lte, data__total_crits__gte, data__total_crits, data__total_heal_crits__lt, data__total_heal_crits__gt, data__total_heal_crits__lte, data__total_heal_crits__gte, data__total_heal_crits, data__total_heals__lt, data__total_heals__gt, data__total_heals__lte, data__total_heals__gte, data__total_heals, data__total_damage_taken__lt, data__total_damage_taken__gt, data__total_damage_taken__lte, data__total_damage_taken__gte, data__total_damage_taken, data__total_attacks_taken__lt, data__total_attacks_taken__gt, data__total_attacks_taken__lte, data__total_attacks_taken__gte, data__total_attacks_taken, data__deaths__lt, data__deaths__gt, data__deaths__lte, data__deaths__gte, data__deaths, data__max_one_hit__lt, data__max_one_hit__gt, data__max_one_hit__lte, data__max_one_hit__gte, data__max_one_hit, data__max_one_hit_weapon, data__max_one_heal__lt, data__max_one_heal__gt, data__max_one_heal__lte, data__max_one_heal__gte, data__max_one_heal, data__max_one_heal_weapon, data__dps__lt, data__dps__gt, data__dps__lte, data__dps__gte, data__dps, data__crith__lt, data__crith__gt, data__crith__lte, data__crith__gte, data__crith, data__heal_crith__lt, data__heal_crith__gt, data__heal_crith__lte, data__heal_crith__gte, data__heal_crith, data__start_time, data__total_time, data__flanks__lt, data__flanks__gt, data__flanks__lte, data__flanks__gte, data__flanks, data__misses__lt, data__misses__gt, data__misses__lte, data__misses__gte, data__misses, data__kills__lt, data__kills__gt, data__kills__lte, data__kills__gte, data__kills, data__runtime, data__end_time, data__accuracy__lt, data__accuracy__gt, data__accuracy__lte, data__accuracy__gte, data__accuracy, data__resist__lt, data__resist__gt, data__resist__lte, data__resist__gte, data__resist, data__hull_attacks__lt, data__hull_attacks__gt, data__hull_attacks__lte, data__hull_attacks__gte, data__hull_attacks, data__final_resist__lt, data__final_resist__gt, data__final_resist__lte, data__final_resist__gte, data__final_resist, data__percent_attacks__lt, data__percent_attacks__gt, data__percent_attacks__lte, data__percent_attacks__gte, data__percent_attacks, data__percent_damage__lt, data__percent_damage__gt, data__percent_damage__lte, data__percent_damage__gte, data__percent_damage, data__percent_damage_taken__lt, data__percent_damage_taken__gt, data__percent_damage_taken__lte, data__percent_damage_taken__gte, data__percent_damage_taken, data__percent_healed__lt, data__percent_healed__gt, data__percent_healed__lte, data__percent_healed__gte, data__percent_healed, data__attacks_per_minute__lt, data__attacks_per_minute__gt, data__attacks_per_minute__lte, data__attacks_per_minute__gte, data__attacks_per_minute, data__hps__lt, data__hps__gt, data__hps__lte, data__hps__gte, data__hps, ordering, page, page_size, async_req=True)
        >>> result = thread.get()

        :param player: player
        :type player: str
        :param ladder: ladder
        :type ladder: str
        :param ladder__name: ladder__name
        :type ladder__name: str
        :param ladder__difficulty: ladder__difficulty
        :type ladder__difficulty: str
        :param data__name: data__name
        :type data__name: str
        :param data__is_player: data__is_player
        :type data__is_player: str
        :param data__total_damage__lt: data__total_damage__lt
        :type data__total_damage__lt: str
        :param data__total_damage__gt: data__total_damage__gt
        :type data__total_damage__gt: str
        :param data__total_damage__lte: data__total_damage__lte
        :type data__total_damage__lte: str
        :param data__total_damage__gte: data__total_damage__gte
        :type data__total_damage__gte: str
        :param data__total_damage: data__total_damage
        :type data__total_damage: str
        :param data__total_attacks__lt: data__total_attacks__lt
        :type data__total_attacks__lt: str
        :param data__total_attacks__gt: data__total_attacks__gt
        :type data__total_attacks__gt: str
        :param data__total_attacks__lte: data__total_attacks__lte
        :type data__total_attacks__lte: str
        :param data__total_attacks__gte: data__total_attacks__gte
        :type data__total_attacks__gte: str
        :param data__total_attacks: data__total_attacks
        :type data__total_attacks: str
        :param data__total_hull_damage__lt: data__total_hull_damage__lt
        :type data__total_hull_damage__lt: str
        :param data__total_hull_damage__gt: data__total_hull_damage__gt
        :type data__total_hull_damage__gt: str
        :param data__total_hull_damage__lte: data__total_hull_damage__lte
        :type data__total_hull_damage__lte: str
        :param data__total_hull_damage__gte: data__total_hull_damage__gte
        :type data__total_hull_damage__gte: str
        :param data__total_hull_damage: data__total_hull_damage
        :type data__total_hull_damage: str
        :param data__total_shield_damage__lt: data__total_shield_damage__lt
        :type data__total_shield_damage__lt: str
        :param data__total_shield_damage__gt: data__total_shield_damage__gt
        :type data__total_shield_damage__gt: str
        :param data__total_shield_damage__lte: data__total_shield_damage__lte
        :type data__total_shield_damage__lte: str
        :param data__total_shield_damage__gte: data__total_shield_damage__gte
        :type data__total_shield_damage__gte: str
        :param data__total_shield_damage: data__total_shield_damage
        :type data__total_shield_damage: str
        :param data__total_heal_instances__lt: data__total_heal_instances__lt
        :type data__total_heal_instances__lt: str
        :param data__total_heal_instances__gt: data__total_heal_instances__gt
        :type data__total_heal_instances__gt: str
        :param data__total_heal_instances__lte: data__total_heal_instances__lte
        :type data__total_heal_instances__lte: str
        :param data__total_heal_instances__gte: data__total_heal_instances__gte
        :type data__total_heal_instances__gte: str
        :param data__total_heal_instances: data__total_heal_instances
        :type data__total_heal_instances: str
        :param data__total_crits__lt: data__total_crits__lt
        :type data__total_crits__lt: str
        :param data__total_crits__gt: data__total_crits__gt
        :type data__total_crits__gt: str
        :param data__total_crits__lte: data__total_crits__lte
        :type data__total_crits__lte: str
        :param data__total_crits__gte: data__total_crits__gte
        :type data__total_crits__gte: str
        :param data__total_crits: data__total_crits
        :type data__total_crits: str
        :param data__total_heal_crits__lt: data__total_heal_crits__lt
        :type data__total_heal_crits__lt: str
        :param data__total_heal_crits__gt: data__total_heal_crits__gt
        :type data__total_heal_crits__gt: str
        :param data__total_heal_crits__lte: data__total_heal_crits__lte
        :type data__total_heal_crits__lte: str
        :param data__total_heal_crits__gte: data__total_heal_crits__gte
        :type data__total_heal_crits__gte: str
        :param data__total_heal_crits: data__total_heal_crits
        :type data__total_heal_crits: str
        :param data__total_heals__lt: data__total_heals__lt
        :type data__total_heals__lt: str
        :param data__total_heals__gt: data__total_heals__gt
        :type data__total_heals__gt: str
        :param data__total_heals__lte: data__total_heals__lte
        :type data__total_heals__lte: str
        :param data__total_heals__gte: data__total_heals__gte
        :type data__total_heals__gte: str
        :param data__total_heals: data__total_heals
        :type data__total_heals: str
        :param data__total_damage_taken__lt: data__total_damage_taken__lt
        :type data__total_damage_taken__lt: str
        :param data__total_damage_taken__gt: data__total_damage_taken__gt
        :type data__total_damage_taken__gt: str
        :param data__total_damage_taken__lte: data__total_damage_taken__lte
        :type data__total_damage_taken__lte: str
        :param data__total_damage_taken__gte: data__total_damage_taken__gte
        :type data__total_damage_taken__gte: str
        :param data__total_damage_taken: data__total_damage_taken
        :type data__total_damage_taken: str
        :param data__total_attacks_taken__lt: data__total_attacks_taken__lt
        :type data__total_attacks_taken__lt: str
        :param data__total_attacks_taken__gt: data__total_attacks_taken__gt
        :type data__total_attacks_taken__gt: str
        :param data__total_attacks_taken__lte: data__total_attacks_taken__lte
        :type data__total_attacks_taken__lte: str
        :param data__total_attacks_taken__gte: data__total_attacks_taken__gte
        :type data__total_attacks_taken__gte: str
        :param data__total_attacks_taken: data__total_attacks_taken
        :type data__total_attacks_taken: str
        :param data__deaths__lt: data__deaths__lt
        :type data__deaths__lt: str
        :param data__deaths__gt: data__deaths__gt
        :type data__deaths__gt: str
        :param data__deaths__lte: data__deaths__lte
        :type data__deaths__lte: str
        :param data__deaths__gte: data__deaths__gte
        :type data__deaths__gte: str
        :param data__deaths: data__deaths
        :type data__deaths: str
        :param data__max_one_hit__lt: data__max_one_hit__lt
        :type data__max_one_hit__lt: str
        :param data__max_one_hit__gt: data__max_one_hit__gt
        :type data__max_one_hit__gt: str
        :param data__max_one_hit__lte: data__max_one_hit__lte
        :type data__max_one_hit__lte: str
        :param data__max_one_hit__gte: data__max_one_hit__gte
        :type data__max_one_hit__gte: str
        :param data__max_one_hit: data__max_one_hit
        :type data__max_one_hit: str
        :param data__max_one_hit_weapon: data__max_one_hit_weapon
        :type data__max_one_hit_weapon: str
        :param data__max_one_heal__lt: data__max_one_heal__lt
        :type data__max_one_heal__lt: str
        :param data__max_one_heal__gt: data__max_one_heal__gt
        :type data__max_one_heal__gt: str
        :param data__max_one_heal__lte: data__max_one_heal__lte
        :type data__max_one_heal__lte: str
        :param data__max_one_heal__gte: data__max_one_heal__gte
        :type data__max_one_heal__gte: str
        :param data__max_one_heal: data__max_one_heal
        :type data__max_one_heal: str
        :param data__max_one_heal_weapon: data__max_one_heal_weapon
        :type data__max_one_heal_weapon: str
        :param data__dps__lt: data__dps__lt
        :type data__dps__lt: str
        :param data__dps__gt: data__dps__gt
        :type data__dps__gt: str
        :param data__dps__lte: data__dps__lte
        :type data__dps__lte: str
        :param data__dps__gte: data__dps__gte
        :type data__dps__gte: str
        :param data__dps: data__dps
        :type data__dps: str
        :param data__crith__lt: data__crith__lt
        :type data__crith__lt: str
        :param data__crith__gt: data__crith__gt
        :type data__crith__gt: str
        :param data__crith__lte: data__crith__lte
        :type data__crith__lte: str
        :param data__crith__gte: data__crith__gte
        :type data__crith__gte: str
        :param data__crith: data__crith
        :type data__crith: str
        :param data__heal_crith__lt: data__heal_crith__lt
        :type data__heal_crith__lt: str
        :param data__heal_crith__gt: data__heal_crith__gt
        :type data__heal_crith__gt: str
        :param data__heal_crith__lte: data__heal_crith__lte
        :type data__heal_crith__lte: str
        :param data__heal_crith__gte: data__heal_crith__gte
        :type data__heal_crith__gte: str
        :param data__heal_crith: data__heal_crith
        :type data__heal_crith: str
        :param data__start_time: data__start_time
        :type data__start_time: str
        :param data__total_time: data__total_time
        :type data__total_time: str
        :param data__flanks__lt: data__flanks__lt
        :type data__flanks__lt: str
        :param data__flanks__gt: data__flanks__gt
        :type data__flanks__gt: str
        :param data__flanks__lte: data__flanks__lte
        :type data__flanks__lte: str
        :param data__flanks__gte: data__flanks__gte
        :type data__flanks__gte: str
        :param data__flanks: data__flanks
        :type data__flanks: str
        :param data__misses__lt: data__misses__lt
        :type data__misses__lt: str
        :param data__misses__gt: data__misses__gt
        :type data__misses__gt: str
        :param data__misses__lte: data__misses__lte
        :type data__misses__lte: str
        :param data__misses__gte: data__misses__gte
        :type data__misses__gte: str
        :param data__misses: data__misses
        :type data__misses: str
        :param data__kills__lt: data__kills__lt
        :type data__kills__lt: str
        :param data__kills__gt: data__kills__gt
        :type data__kills__gt: str
        :param data__kills__lte: data__kills__lte
        :type data__kills__lte: str
        :param data__kills__gte: data__kills__gte
        :type data__kills__gte: str
        :param data__kills: data__kills
        :type data__kills: str
        :param data__runtime: data__runtime
        :type data__runtime: str
        :param data__end_time: data__end_time
        :type data__end_time: str
        :param data__accuracy__lt: data__accuracy__lt
        :type data__accuracy__lt: str
        :param data__accuracy__gt: data__accuracy__gt
        :type data__accuracy__gt: str
        :param data__accuracy__lte: data__accuracy__lte
        :type data__accuracy__lte: str
        :param data__accuracy__gte: data__accuracy__gte
        :type data__accuracy__gte: str
        :param data__accuracy: data__accuracy
        :type data__accuracy: str
        :param data__resist__lt: data__resist__lt
        :type data__resist__lt: str
        :param data__resist__gt: data__resist__gt
        :type data__resist__gt: str
        :param data__resist__lte: data__resist__lte
        :type data__resist__lte: str
        :param data__resist__gte: data__resist__gte
        :type data__resist__gte: str
        :param data__resist: data__resist
        :type data__resist: str
        :param data__hull_attacks__lt: data__hull_attacks__lt
        :type data__hull_attacks__lt: str
        :param data__hull_attacks__gt: data__hull_attacks__gt
        :type data__hull_attacks__gt: str
        :param data__hull_attacks__lte: data__hull_attacks__lte
        :type data__hull_attacks__lte: str
        :param data__hull_attacks__gte: data__hull_attacks__gte
        :type data__hull_attacks__gte: str
        :param data__hull_attacks: data__hull_attacks
        :type data__hull_attacks: str
        :param data__final_resist__lt: data__final_resist__lt
        :type data__final_resist__lt: str
        :param data__final_resist__gt: data__final_resist__gt
        :type data__final_resist__gt: str
        :param data__final_resist__lte: data__final_resist__lte
        :type data__final_resist__lte: str
        :param data__final_resist__gte: data__final_resist__gte
        :type data__final_resist__gte: str
        :param data__final_resist: data__final_resist
        :type data__final_resist: str
        :param data__percent_attacks__lt: data__percent_attacks__lt
        :type data__percent_attacks__lt: str
        :param data__percent_attacks__gt: data__percent_attacks__gt
        :type data__percent_attacks__gt: str
        :param data__percent_attacks__lte: data__percent_attacks__lte
        :type data__percent_attacks__lte: str
        :param data__percent_attacks__gte: data__percent_attacks__gte
        :type data__percent_attacks__gte: str
        :param data__percent_attacks: data__percent_attacks
        :type data__percent_attacks: str
        :param data__percent_damage__lt: data__percent_damage__lt
        :type data__percent_damage__lt: str
        :param data__percent_damage__gt: data__percent_damage__gt
        :type data__percent_damage__gt: str
        :param data__percent_damage__lte: data__percent_damage__lte
        :type data__percent_damage__lte: str
        :param data__percent_damage__gte: data__percent_damage__gte
        :type data__percent_damage__gte: str
        :param data__percent_damage: data__percent_damage
        :type data__percent_damage: str
        :param data__percent_damage_taken__lt: data__percent_damage_taken__lt
        :type data__percent_damage_taken__lt: str
        :param data__percent_damage_taken__gt: data__percent_damage_taken__gt
        :type data__percent_damage_taken__gt: str
        :param data__percent_damage_taken__lte: data__percent_damage_taken__lte
        :type data__percent_damage_taken__lte: str
        :param data__percent_damage_taken__gte: data__percent_damage_taken__gte
        :type data__percent_damage_taken__gte: str
        :param data__percent_damage_taken: data__percent_damage_taken
        :type data__percent_damage_taken: str
        :param data__percent_healed__lt: data__percent_healed__lt
        :type data__percent_healed__lt: str
        :param data__percent_healed__gt: data__percent_healed__gt
        :type data__percent_healed__gt: str
        :param data__percent_healed__lte: data__percent_healed__lte
        :type data__percent_healed__lte: str
        :param data__percent_healed__gte: data__percent_healed__gte
        :type data__percent_healed__gte: str
        :param data__percent_healed: data__percent_healed
        :type data__percent_healed: str
        :param data__attacks_per_minute__lt: data__attacks_per_minute__lt
        :type data__attacks_per_minute__lt: str
        :param data__attacks_per_minute__gt: data__attacks_per_minute__gt
        :type data__attacks_per_minute__gt: str
        :param data__attacks_per_minute__lte: data__attacks_per_minute__lte
        :type data__attacks_per_minute__lte: str
        :param data__attacks_per_minute__gte: data__attacks_per_minute__gte
        :type data__attacks_per_minute__gte: str
        :param data__attacks_per_minute: data__attacks_per_minute
        :type data__attacks_per_minute: str
        :param data__hps__lt: data__hps__lt
        :type data__hps__lt: str
        :param data__hps__gt: data__hps__gt
        :type data__hps__gt: str
        :param data__hps__lte: data__hps__lte
        :type data__hps__lte: str
        :param data__hps__gte: data__hps__gte
        :type data__hps__gte: str
        :param data__hps: data__hps
        :type data__hps: str
        :param ordering: Which field to use when ordering the results.
        :type ordering: str
        :param page: A page number within the paginated result set.
        :type page: int
        :param page_size: Number of results to return per page.
        :type page_size: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: LadderEntriesList200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the ladder_entries_list_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.ladder_entries_list_with_http_info(player, ladder, ladder__name, ladder__difficulty, data__name, data__is_player, data__total_damage__lt, data__total_damage__gt, data__total_damage__lte, data__total_damage__gte, data__total_damage, data__total_attacks__lt, data__total_attacks__gt, data__total_attacks__lte, data__total_attacks__gte, data__total_attacks, data__total_hull_damage__lt, data__total_hull_damage__gt, data__total_hull_damage__lte, data__total_hull_damage__gte, data__total_hull_damage, data__total_shield_damage__lt, data__total_shield_damage__gt, data__total_shield_damage__lte, data__total_shield_damage__gte, data__total_shield_damage, data__total_heal_instances__lt, data__total_heal_instances__gt, data__total_heal_instances__lte, data__total_heal_instances__gte, data__total_heal_instances, data__total_crits__lt, data__total_crits__gt, data__total_crits__lte, data__total_crits__gte, data__total_crits, data__total_heal_crits__lt, data__total_heal_crits__gt, data__total_heal_crits__lte, data__total_heal_crits__gte, data__total_heal_crits, data__total_heals__lt, data__total_heals__gt, data__total_heals__lte, data__total_heals__gte, data__total_heals, data__total_damage_taken__lt, data__total_damage_taken__gt, data__total_damage_taken__lte, data__total_damage_taken__gte, data__total_damage_taken, data__total_attacks_taken__lt, data__total_attacks_taken__gt, data__total_attacks_taken__lte, data__total_attacks_taken__gte, data__total_attacks_taken, data__deaths__lt, data__deaths__gt, data__deaths__lte, data__deaths__gte, data__deaths, data__max_one_hit__lt, data__max_one_hit__gt, data__max_one_hit__lte, data__max_one_hit__gte, data__max_one_hit, data__max_one_hit_weapon, data__max_one_heal__lt, data__max_one_heal__gt, data__max_one_heal__lte, data__max_one_heal__gte, data__max_one_heal, data__max_one_heal_weapon, data__dps__lt, data__dps__gt, data__dps__lte, data__dps__gte, data__dps, data__crith__lt, data__crith__gt, data__crith__lte, data__crith__gte, data__crith, data__heal_crith__lt, data__heal_crith__gt, data__heal_crith__lte, data__heal_crith__gte, data__heal_crith, data__start_time, data__total_time, data__flanks__lt, data__flanks__gt, data__flanks__lte, data__flanks__gte, data__flanks, data__misses__lt, data__misses__gt, data__misses__lte, data__misses__gte, data__misses, data__kills__lt, data__kills__gt, data__kills__lte, data__kills__gte, data__kills, data__runtime, data__end_time, data__accuracy__lt, data__accuracy__gt, data__accuracy__lte, data__accuracy__gte, data__accuracy, data__resist__lt, data__resist__gt, data__resist__lte, data__resist__gte, data__resist, data__hull_attacks__lt, data__hull_attacks__gt, data__hull_attacks__lte, data__hull_attacks__gte, data__hull_attacks, data__final_resist__lt, data__final_resist__gt, data__final_resist__lte, data__final_resist__gte, data__final_resist, data__percent_attacks__lt, data__percent_attacks__gt, data__percent_attacks__lte, data__percent_attacks__gte, data__percent_attacks, data__percent_damage__lt, data__percent_damage__gt, data__percent_damage__lte, data__percent_damage__gte, data__percent_damage, data__percent_damage_taken__lt, data__percent_damage_taken__gt, data__percent_damage_taken__lte, data__percent_damage_taken__gte, data__percent_damage_taken, data__percent_healed__lt, data__percent_healed__gt, data__percent_healed__lte, data__percent_healed__gte, data__percent_healed, data__attacks_per_minute__lt, data__attacks_per_minute__gt, data__attacks_per_minute__lte, data__attacks_per_minute__gte, data__attacks_per_minute, data__hps__lt, data__hps__gt, data__hps__lte, data__hps__gte, data__hps, ordering, page, page_size, **kwargs)  # noqa: E501

    @validate_arguments
    def ladder_entries_list_with_http_info(self, player : Annotated[Optional[StrictStr], Field(description="player")] = None, ladder : Annotated[Optional[StrictStr], Field(description="ladder")] = None, ladder__name : Annotated[Optional[StrictStr], Field(description="ladder__name")] = None, ladder__difficulty : Annotated[Optional[StrictStr], Field(description="ladder__difficulty")] = None, data__name : Annotated[Optional[StrictStr], Field(description="data__name")] = None, data__is_player : Annotated[Optional[StrictStr], Field(description="data__is_player")] = None, data__total_damage__lt : Annotated[Optional[StrictStr], Field(description="data__total_damage__lt")] = None, data__total_damage__gt : Annotated[Optional[StrictStr], Field(description="data__total_damage__gt")] = None, data__total_damage__lte : Annotated[Optional[StrictStr], Field(description="data__total_damage__lte")] = None, data__total_damage__gte : Annotated[Optional[StrictStr], Field(description="data__total_damage__gte")] = None, data__total_damage : Annotated[Optional[StrictStr], Field(description="data__total_damage")] = None, data__total_attacks__lt : Annotated[Optional[StrictStr], Field(description="data__total_attacks__lt")] = None, data__total_attacks__gt : Annotated[Optional[StrictStr], Field(description="data__total_attacks__gt")] = None, data__total_attacks__lte : Annotated[Optional[StrictStr], Field(description="data__total_attacks__lte")] = None, data__total_attacks__gte : Annotated[Optional[StrictStr], Field(description="data__total_attacks__gte")] = None, data__total_attacks : Annotated[Optional[StrictStr], Field(description="data__total_attacks")] = None, data__total_hull_damage__lt : Annotated[Optional[StrictStr], Field(description="data__total_hull_damage__lt")] = None, data__total_hull_damage__gt : Annotated[Optional[StrictStr], Field(description="data__total_hull_damage__gt")] = None, data__total_hull_damage__lte : Annotated[Optional[StrictStr], Field(description="data__total_hull_damage__lte")] = None, data__total_hull_damage__gte : Annotated[Optional[StrictStr], Field(description="data__total_hull_damage__gte")] = None, data__total_hull_damage : Annotated[Optional[StrictStr], Field(description="data__total_hull_damage")] = None, data__total_shield_damage__lt : Annotated[Optional[StrictStr], Field(description="data__total_shield_damage__lt")] = None, data__total_shield_damage__gt : Annotated[Optional[StrictStr], Field(description="data__total_shield_damage__gt")] = None, data__total_shield_damage__lte : Annotated[Optional[StrictStr], Field(description="data__total_shield_damage__lte")] = None, data__total_shield_damage__gte : Annotated[Optional[StrictStr], Field(description="data__total_shield_damage__gte")] = None, data__total_shield_damage : Annotated[Optional[StrictStr], Field(description="data__total_shield_damage")] = None, data__total_heal_instances__lt : Annotated[Optional[StrictStr], Field(description="data__total_heal_instances__lt")] = None, data__total_heal_instances__gt : Annotated[Optional[StrictStr], Field(description="data__total_heal_instances__gt")] = None, data__total_heal_instances__lte : Annotated[Optional[StrictStr], Field(description="data__total_heal_instances__lte")] = None, data__total_heal_instances__gte : Annotated[Optional[StrictStr], Field(description="data__total_heal_instances__gte")] = None, data__total_heal_instances : Annotated[Optional[StrictStr], Field(description="data__total_heal_instances")] = None, data__total_crits__lt : Annotated[Optional[StrictStr], Field(description="data__total_crits__lt")] = None, data__total_crits__gt : Annotated[Optional[StrictStr], Field(description="data__total_crits__gt")] = None, data__total_crits__lte : Annotated[Optional[StrictStr], Field(description="data__total_crits__lte")] = None, data__total_crits__gte : Annotated[Optional[StrictStr], Field(description="data__total_crits__gte")] = None, data__total_crits : Annotated[Optional[StrictStr], Field(description="data__total_crits")] = None, data__total_heal_crits__lt : Annotated[Optional[StrictStr], Field(description="data__total_heal_crits__lt")] = None, data__total_heal_crits__gt : Annotated[Optional[StrictStr], Field(description="data__total_heal_crits__gt")] = None, data__total_heal_crits__lte : Annotated[Optional[StrictStr], Field(description="data__total_heal_crits__lte")] = None, data__total_heal_crits__gte : Annotated[Optional[StrictStr], Field(description="data__total_heal_crits__gte")] = None, data__total_heal_crits : Annotated[Optional[StrictStr], Field(description="data__total_heal_crits")] = None, data__total_heals__lt : Annotated[Optional[StrictStr], Field(description="data__total_heals__lt")] = None, data__total_heals__gt : Annotated[Optional[StrictStr], Field(description="data__total_heals__gt")] = None, data__total_heals__lte : Annotated[Optional[StrictStr], Field(description="data__total_heals__lte")] = None, data__total_heals__gte : Annotated[Optional[StrictStr], Field(description="data__total_heals__gte")] = None, data__total_heals : Annotated[Optional[StrictStr], Field(description="data__total_heals")] = None, data__total_damage_taken__lt : Annotated[Optional[StrictStr], Field(description="data__total_damage_taken__lt")] = None, data__total_damage_taken__gt : Annotated[Optional[StrictStr], Field(description="data__total_damage_taken__gt")] = None, data__total_damage_taken__lte : Annotated[Optional[StrictStr], Field(description="data__total_damage_taken__lte")] = None, data__total_damage_taken__gte : Annotated[Optional[StrictStr], Field(description="data__total_damage_taken__gte")] = None, data__total_damage_taken : Annotated[Optional[StrictStr], Field(description="data__total_damage_taken")] = None, data__total_attacks_taken__lt : Annotated[Optional[StrictStr], Field(description="data__total_attacks_taken__lt")] = None, data__total_attacks_taken__gt : Annotated[Optional[StrictStr], Field(description="data__total_attacks_taken__gt")] = None, data__total_attacks_taken__lte : Annotated[Optional[StrictStr], Field(description="data__total_attacks_taken__lte")] = None, data__total_attacks_taken__gte : Annotated[Optional[StrictStr], Field(description="data__total_attacks_taken__gte")] = None, data__total_attacks_taken : Annotated[Optional[StrictStr], Field(description="data__total_attacks_taken")] = None, data__deaths__lt : Annotated[Optional[StrictStr], Field(description="data__deaths__lt")] = None, data__deaths__gt : Annotated[Optional[StrictStr], Field(description="data__deaths__gt")] = None, data__deaths__lte : Annotated[Optional[StrictStr], Field(description="data__deaths__lte")] = None, data__deaths__gte : Annotated[Optional[StrictStr], Field(description="data__deaths__gte")] = None, data__deaths : Annotated[Optional[StrictStr], Field(description="data__deaths")] = None, data__max_one_hit__lt : Annotated[Optional[StrictStr], Field(description="data__max_one_hit__lt")] = None, data__max_one_hit__gt : Annotated[Optional[StrictStr], Field(description="data__max_one_hit__gt")] = None, data__max_one_hit__lte : Annotated[Optional[StrictStr], Field(description="data__max_one_hit__lte")] = None, data__max_one_hit__gte : Annotated[Optional[StrictStr], Field(description="data__max_one_hit__gte")] = None, data__max_one_hit : Annotated[Optional[StrictStr], Field(description="data__max_one_hit")] = None, data__max_one_hit_weapon : Annotated[Optional[StrictStr], Field(description="data__max_one_hit_weapon")] = None, data__max_one_heal__lt : Annotated[Optional[StrictStr], Field(description="data__max_one_heal__lt")] = None, data__max_one_heal__gt : Annotated[Optional[StrictStr], Field(description="data__max_one_heal__gt")] = None, data__max_one_heal__lte : Annotated[Optional[StrictStr], Field(description="data__max_one_heal__lte")] = None, data__max_one_heal__gte : Annotated[Optional[StrictStr], Field(description="data__max_one_heal__gte")] = None, data__max_one_heal : Annotated[Optional[StrictStr], Field(description="data__max_one_heal")] = None, data__max_one_heal_weapon : Annotated[Optional[StrictStr], Field(description="data__max_one_heal_weapon")] = None, data__dps__lt : Annotated[Optional[StrictStr], Field(description="data__dps__lt")] = None, data__dps__gt : Annotated[Optional[StrictStr], Field(description="data__dps__gt")] = None, data__dps__lte : Annotated[Optional[StrictStr], Field(description="data__dps__lte")] = None, data__dps__gte : Annotated[Optional[StrictStr], Field(description="data__dps__gte")] = None, data__dps : Annotated[Optional[StrictStr], Field(description="data__dps")] = None, data__crith__lt : Annotated[Optional[StrictStr], Field(description="data__crith__lt")] = None, data__crith__gt : Annotated[Optional[StrictStr], Field(description="data__crith__gt")] = None, data__crith__lte : Annotated[Optional[StrictStr], Field(description="data__crith__lte")] = None, data__crith__gte : Annotated[Optional[StrictStr], Field(description="data__crith__gte")] = None, data__crith : Annotated[Optional[StrictStr], Field(description="data__crith")] = None, data__heal_crith__lt : Annotated[Optional[StrictStr], Field(description="data__heal_crith__lt")] = None, data__heal_crith__gt : Annotated[Optional[StrictStr], Field(description="data__heal_crith__gt")] = None, data__heal_crith__lte : Annotated[Optional[StrictStr], Field(description="data__heal_crith__lte")] = None, data__heal_crith__gte : Annotated[Optional[StrictStr], Field(description="data__heal_crith__gte")] = None, data__heal_crith : Annotated[Optional[StrictStr], Field(description="data__heal_crith")] = None, data__start_time : Annotated[Optional[StrictStr], Field(description="data__start_time")] = None, data__total_time : Annotated[Optional[StrictStr], Field(description="data__total_time")] = None, data__flanks__lt : Annotated[Optional[StrictStr], Field(description="data__flanks__lt")] = None, data__flanks__gt : Annotated[Optional[StrictStr], Field(description="data__flanks__gt")] = None, data__flanks__lte : Annotated[Optional[StrictStr], Field(description="data__flanks__lte")] = None, data__flanks__gte : Annotated[Optional[StrictStr], Field(description="data__flanks__gte")] = None, data__flanks : Annotated[Optional[StrictStr], Field(description="data__flanks")] = None, data__misses__lt : Annotated[Optional[StrictStr], Field(description="data__misses__lt")] = None, data__misses__gt : Annotated[Optional[StrictStr], Field(description="data__misses__gt")] = None, data__misses__lte : Annotated[Optional[StrictStr], Field(description="data__misses__lte")] = None, data__misses__gte : Annotated[Optional[StrictStr], Field(description="data__misses__gte")] = None, data__misses : Annotated[Optional[StrictStr], Field(description="data__misses")] = None, data__kills__lt : Annotated[Optional[StrictStr], Field(description="data__kills__lt")] = None, data__kills__gt : Annotated[Optional[StrictStr], Field(description="data__kills__gt")] = None, data__kills__lte : Annotated[Optional[StrictStr], Field(description="data__kills__lte")] = None, data__kills__gte : Annotated[Optional[StrictStr], Field(description="data__kills__gte")] = None, data__kills : Annotated[Optional[StrictStr], Field(description="data__kills")] = None, data__runtime : Annotated[Optional[StrictStr], Field(description="data__runtime")] = None, data__end_time : Annotated[Optional[StrictStr], Field(description="data__end_time")] = None, data__accuracy__lt : Annotated[Optional[StrictStr], Field(description="data__accuracy__lt")] = None, data__accuracy__gt : Annotated[Optional[StrictStr], Field(description="data__accuracy__gt")] = None, data__accuracy__lte : Annotated[Optional[StrictStr], Field(description="data__accuracy__lte")] = None, data__accuracy__gte : Annotated[Optional[StrictStr], Field(description="data__accuracy__gte")] = None, data__accuracy : Annotated[Optional[StrictStr], Field(description="data__accuracy")] = None, data__resist__lt : Annotated[Optional[StrictStr], Field(description="data__resist__lt")] = None, data__resist__gt : Annotated[Optional[StrictStr], Field(description="data__resist__gt")] = None, data__resist__lte : Annotated[Optional[StrictStr], Field(description="data__resist__lte")] = None, data__resist__gte : Annotated[Optional[StrictStr], Field(description="data__resist__gte")] = None, data__resist : Annotated[Optional[StrictStr], Field(description="data__resist")] = None, data__hull_attacks__lt : Annotated[Optional[StrictStr], Field(description="data__hull_attacks__lt")] = None, data__hull_attacks__gt : Annotated[Optional[StrictStr], Field(description="data__hull_attacks__gt")] = None, data__hull_attacks__lte : Annotated[Optional[StrictStr], Field(description="data__hull_attacks__lte")] = None, data__hull_attacks__gte : Annotated[Optional[StrictStr], Field(description="data__hull_attacks__gte")] = None, data__hull_attacks : Annotated[Optional[StrictStr], Field(description="data__hull_attacks")] = None, data__final_resist__lt : Annotated[Optional[StrictStr], Field(description="data__final_resist__lt")] = None, data__final_resist__gt : Annotated[Optional[StrictStr], Field(description="data__final_resist__gt")] = None, data__final_resist__lte : Annotated[Optional[StrictStr], Field(description="data__final_resist__lte")] = None, data__final_resist__gte : Annotated[Optional[StrictStr], Field(description="data__final_resist__gte")] = None, data__final_resist : Annotated[Optional[StrictStr], Field(description="data__final_resist")] = None, data__percent_attacks__lt : Annotated[Optional[StrictStr], Field(description="data__percent_attacks__lt")] = None, data__percent_attacks__gt : Annotated[Optional[StrictStr], Field(description="data__percent_attacks__gt")] = None, data__percent_attacks__lte : Annotated[Optional[StrictStr], Field(description="data__percent_attacks__lte")] = None, data__percent_attacks__gte : Annotated[Optional[StrictStr], Field(description="data__percent_attacks__gte")] = None, data__percent_attacks : Annotated[Optional[StrictStr], Field(description="data__percent_attacks")] = None, data__percent_damage__lt : Annotated[Optional[StrictStr], Field(description="data__percent_damage__lt")] = None, data__percent_damage__gt : Annotated[Optional[StrictStr], Field(description="data__percent_damage__gt")] = None, data__percent_damage__lte : Annotated[Optional[StrictStr], Field(description="data__percent_damage__lte")] = None, data__percent_damage__gte : Annotated[Optional[StrictStr], Field(description="data__percent_damage__gte")] = None, data__percent_damage : Annotated[Optional[StrictStr], Field(description="data__percent_damage")] = None, data__percent_damage_taken__lt : Annotated[Optional[StrictStr], Field(description="data__percent_damage_taken__lt")] = None, data__percent_damage_taken__gt : Annotated[Optional[StrictStr], Field(description="data__percent_damage_taken__gt")] = None, data__percent_damage_taken__lte : Annotated[Optional[StrictStr], Field(description="data__percent_damage_taken__lte")] = None, data__percent_damage_taken__gte : Annotated[Optional[StrictStr], Field(description="data__percent_damage_taken__gte")] = None, data__percent_damage_taken : Annotated[Optional[StrictStr], Field(description="data__percent_damage_taken")] = None, data__percent_healed__lt : Annotated[Optional[StrictStr], Field(description="data__percent_healed__lt")] = None, data__percent_healed__gt : Annotated[Optional[StrictStr], Field(description="data__percent_healed__gt")] = None, data__percent_healed__lte : Annotated[Optional[StrictStr], Field(description="data__percent_healed__lte")] = None, data__percent_healed__gte : Annotated[Optional[StrictStr], Field(description="data__percent_healed__gte")] = None, data__percent_healed : Annotated[Optional[StrictStr], Field(description="data__percent_healed")] = None, data__attacks_per_minute__lt : Annotated[Optional[StrictStr], Field(description="data__attacks_per_minute__lt")] = None, data__attacks_per_minute__gt : Annotated[Optional[StrictStr], Field(description="data__attacks_per_minute__gt")] = None, data__attacks_per_minute__lte : Annotated[Optional[StrictStr], Field(description="data__attacks_per_minute__lte")] = None, data__attacks_per_minute__gte : Annotated[Optional[StrictStr], Field(description="data__attacks_per_minute__gte")] = None, data__attacks_per_minute : Annotated[Optional[StrictStr], Field(description="data__attacks_per_minute")] = None, data__hps__lt : Annotated[Optional[StrictStr], Field(description="data__hps__lt")] = None, data__hps__gt : Annotated[Optional[StrictStr], Field(description="data__hps__gt")] = None, data__hps__lte : Annotated[Optional[StrictStr], Field(description="data__hps__lte")] = None, data__hps__gte : Annotated[Optional[StrictStr], Field(description="data__hps__gte")] = None, data__hps : Annotated[Optional[StrictStr], Field(description="data__hps")] = None, ordering : Annotated[Optional[StrictStr], Field(description="Which field to use when ordering the results.")] = None, page : Annotated[Optional[StrictInt], Field(description="A page number within the paginated result set.")] = None, page_size : Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """ladder_entries_list  # noqa: E501

        LadderEntry API  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.ladder_entries_list_with_http_info(player, ladder, ladder__name, ladder__difficulty, data__name, data__is_player, data__total_damage__lt, data__total_damage__gt, data__total_damage__lte, data__total_damage__gte, data__total_damage, data__total_attacks__lt, data__total_attacks__gt, data__total_attacks__lte, data__total_attacks__gte, data__total_attacks, data__total_hull_damage__lt, data__total_hull_damage__gt, data__total_hull_damage__lte, data__total_hull_damage__gte, data__total_hull_damage, data__total_shield_damage__lt, data__total_shield_damage__gt, data__total_shield_damage__lte, data__total_shield_damage__gte, data__total_shield_damage, data__total_heal_instances__lt, data__total_heal_instances__gt, data__total_heal_instances__lte, data__total_heal_instances__gte, data__total_heal_instances, data__total_crits__lt, data__total_crits__gt, data__total_crits__lte, data__total_crits__gte, data__total_crits, data__total_heal_crits__lt, data__total_heal_crits__gt, data__total_heal_crits__lte, data__total_heal_crits__gte, data__total_heal_crits, data__total_heals__lt, data__total_heals__gt, data__total_heals__lte, data__total_heals__gte, data__total_heals, data__total_damage_taken__lt, data__total_damage_taken__gt, data__total_damage_taken__lte, data__total_damage_taken__gte, data__total_damage_taken, data__total_attacks_taken__lt, data__total_attacks_taken__gt, data__total_attacks_taken__lte, data__total_attacks_taken__gte, data__total_attacks_taken, data__deaths__lt, data__deaths__gt, data__deaths__lte, data__deaths__gte, data__deaths, data__max_one_hit__lt, data__max_one_hit__gt, data__max_one_hit__lte, data__max_one_hit__gte, data__max_one_hit, data__max_one_hit_weapon, data__max_one_heal__lt, data__max_one_heal__gt, data__max_one_heal__lte, data__max_one_heal__gte, data__max_one_heal, data__max_one_heal_weapon, data__dps__lt, data__dps__gt, data__dps__lte, data__dps__gte, data__dps, data__crith__lt, data__crith__gt, data__crith__lte, data__crith__gte, data__crith, data__heal_crith__lt, data__heal_crith__gt, data__heal_crith__lte, data__heal_crith__gte, data__heal_crith, data__start_time, data__total_time, data__flanks__lt, data__flanks__gt, data__flanks__lte, data__flanks__gte, data__flanks, data__misses__lt, data__misses__gt, data__misses__lte, data__misses__gte, data__misses, data__kills__lt, data__kills__gt, data__kills__lte, data__kills__gte, data__kills, data__runtime, data__end_time, data__accuracy__lt, data__accuracy__gt, data__accuracy__lte, data__accuracy__gte, data__accuracy, data__resist__lt, data__resist__gt, data__resist__lte, data__resist__gte, data__resist, data__hull_attacks__lt, data__hull_attacks__gt, data__hull_attacks__lte, data__hull_attacks__gte, data__hull_attacks, data__final_resist__lt, data__final_resist__gt, data__final_resist__lte, data__final_resist__gte, data__final_resist, data__percent_attacks__lt, data__percent_attacks__gt, data__percent_attacks__lte, data__percent_attacks__gte, data__percent_attacks, data__percent_damage__lt, data__percent_damage__gt, data__percent_damage__lte, data__percent_damage__gte, data__percent_damage, data__percent_damage_taken__lt, data__percent_damage_taken__gt, data__percent_damage_taken__lte, data__percent_damage_taken__gte, data__percent_damage_taken, data__percent_healed__lt, data__percent_healed__gt, data__percent_healed__lte, data__percent_healed__gte, data__percent_healed, data__attacks_per_minute__lt, data__attacks_per_minute__gt, data__attacks_per_minute__lte, data__attacks_per_minute__gte, data__attacks_per_minute, data__hps__lt, data__hps__gt, data__hps__lte, data__hps__gte, data__hps, ordering, page, page_size, async_req=True)
        >>> result = thread.get()

        :param player: player
        :type player: str
        :param ladder: ladder
        :type ladder: str
        :param ladder__name: ladder__name
        :type ladder__name: str
        :param ladder__difficulty: ladder__difficulty
        :type ladder__difficulty: str
        :param data__name: data__name
        :type data__name: str
        :param data__is_player: data__is_player
        :type data__is_player: str
        :param data__total_damage__lt: data__total_damage__lt
        :type data__total_damage__lt: str
        :param data__total_damage__gt: data__total_damage__gt
        :type data__total_damage__gt: str
        :param data__total_damage__lte: data__total_damage__lte
        :type data__total_damage__lte: str
        :param data__total_damage__gte: data__total_damage__gte
        :type data__total_damage__gte: str
        :param data__total_damage: data__total_damage
        :type data__total_damage: str
        :param data__total_attacks__lt: data__total_attacks__lt
        :type data__total_attacks__lt: str
        :param data__total_attacks__gt: data__total_attacks__gt
        :type data__total_attacks__gt: str
        :param data__total_attacks__lte: data__total_attacks__lte
        :type data__total_attacks__lte: str
        :param data__total_attacks__gte: data__total_attacks__gte
        :type data__total_attacks__gte: str
        :param data__total_attacks: data__total_attacks
        :type data__total_attacks: str
        :param data__total_hull_damage__lt: data__total_hull_damage__lt
        :type data__total_hull_damage__lt: str
        :param data__total_hull_damage__gt: data__total_hull_damage__gt
        :type data__total_hull_damage__gt: str
        :param data__total_hull_damage__lte: data__total_hull_damage__lte
        :type data__total_hull_damage__lte: str
        :param data__total_hull_damage__gte: data__total_hull_damage__gte
        :type data__total_hull_damage__gte: str
        :param data__total_hull_damage: data__total_hull_damage
        :type data__total_hull_damage: str
        :param data__total_shield_damage__lt: data__total_shield_damage__lt
        :type data__total_shield_damage__lt: str
        :param data__total_shield_damage__gt: data__total_shield_damage__gt
        :type data__total_shield_damage__gt: str
        :param data__total_shield_damage__lte: data__total_shield_damage__lte
        :type data__total_shield_damage__lte: str
        :param data__total_shield_damage__gte: data__total_shield_damage__gte
        :type data__total_shield_damage__gte: str
        :param data__total_shield_damage: data__total_shield_damage
        :type data__total_shield_damage: str
        :param data__total_heal_instances__lt: data__total_heal_instances__lt
        :type data__total_heal_instances__lt: str
        :param data__total_heal_instances__gt: data__total_heal_instances__gt
        :type data__total_heal_instances__gt: str
        :param data__total_heal_instances__lte: data__total_heal_instances__lte
        :type data__total_heal_instances__lte: str
        :param data__total_heal_instances__gte: data__total_heal_instances__gte
        :type data__total_heal_instances__gte: str
        :param data__total_heal_instances: data__total_heal_instances
        :type data__total_heal_instances: str
        :param data__total_crits__lt: data__total_crits__lt
        :type data__total_crits__lt: str
        :param data__total_crits__gt: data__total_crits__gt
        :type data__total_crits__gt: str
        :param data__total_crits__lte: data__total_crits__lte
        :type data__total_crits__lte: str
        :param data__total_crits__gte: data__total_crits__gte
        :type data__total_crits__gte: str
        :param data__total_crits: data__total_crits
        :type data__total_crits: str
        :param data__total_heal_crits__lt: data__total_heal_crits__lt
        :type data__total_heal_crits__lt: str
        :param data__total_heal_crits__gt: data__total_heal_crits__gt
        :type data__total_heal_crits__gt: str
        :param data__total_heal_crits__lte: data__total_heal_crits__lte
        :type data__total_heal_crits__lte: str
        :param data__total_heal_crits__gte: data__total_heal_crits__gte
        :type data__total_heal_crits__gte: str
        :param data__total_heal_crits: data__total_heal_crits
        :type data__total_heal_crits: str
        :param data__total_heals__lt: data__total_heals__lt
        :type data__total_heals__lt: str
        :param data__total_heals__gt: data__total_heals__gt
        :type data__total_heals__gt: str
        :param data__total_heals__lte: data__total_heals__lte
        :type data__total_heals__lte: str
        :param data__total_heals__gte: data__total_heals__gte
        :type data__total_heals__gte: str
        :param data__total_heals: data__total_heals
        :type data__total_heals: str
        :param data__total_damage_taken__lt: data__total_damage_taken__lt
        :type data__total_damage_taken__lt: str
        :param data__total_damage_taken__gt: data__total_damage_taken__gt
        :type data__total_damage_taken__gt: str
        :param data__total_damage_taken__lte: data__total_damage_taken__lte
        :type data__total_damage_taken__lte: str
        :param data__total_damage_taken__gte: data__total_damage_taken__gte
        :type data__total_damage_taken__gte: str
        :param data__total_damage_taken: data__total_damage_taken
        :type data__total_damage_taken: str
        :param data__total_attacks_taken__lt: data__total_attacks_taken__lt
        :type data__total_attacks_taken__lt: str
        :param data__total_attacks_taken__gt: data__total_attacks_taken__gt
        :type data__total_attacks_taken__gt: str
        :param data__total_attacks_taken__lte: data__total_attacks_taken__lte
        :type data__total_attacks_taken__lte: str
        :param data__total_attacks_taken__gte: data__total_attacks_taken__gte
        :type data__total_attacks_taken__gte: str
        :param data__total_attacks_taken: data__total_attacks_taken
        :type data__total_attacks_taken: str
        :param data__deaths__lt: data__deaths__lt
        :type data__deaths__lt: str
        :param data__deaths__gt: data__deaths__gt
        :type data__deaths__gt: str
        :param data__deaths__lte: data__deaths__lte
        :type data__deaths__lte: str
        :param data__deaths__gte: data__deaths__gte
        :type data__deaths__gte: str
        :param data__deaths: data__deaths
        :type data__deaths: str
        :param data__max_one_hit__lt: data__max_one_hit__lt
        :type data__max_one_hit__lt: str
        :param data__max_one_hit__gt: data__max_one_hit__gt
        :type data__max_one_hit__gt: str
        :param data__max_one_hit__lte: data__max_one_hit__lte
        :type data__max_one_hit__lte: str
        :param data__max_one_hit__gte: data__max_one_hit__gte
        :type data__max_one_hit__gte: str
        :param data__max_one_hit: data__max_one_hit
        :type data__max_one_hit: str
        :param data__max_one_hit_weapon: data__max_one_hit_weapon
        :type data__max_one_hit_weapon: str
        :param data__max_one_heal__lt: data__max_one_heal__lt
        :type data__max_one_heal__lt: str
        :param data__max_one_heal__gt: data__max_one_heal__gt
        :type data__max_one_heal__gt: str
        :param data__max_one_heal__lte: data__max_one_heal__lte
        :type data__max_one_heal__lte: str
        :param data__max_one_heal__gte: data__max_one_heal__gte
        :type data__max_one_heal__gte: str
        :param data__max_one_heal: data__max_one_heal
        :type data__max_one_heal: str
        :param data__max_one_heal_weapon: data__max_one_heal_weapon
        :type data__max_one_heal_weapon: str
        :param data__dps__lt: data__dps__lt
        :type data__dps__lt: str
        :param data__dps__gt: data__dps__gt
        :type data__dps__gt: str
        :param data__dps__lte: data__dps__lte
        :type data__dps__lte: str
        :param data__dps__gte: data__dps__gte
        :type data__dps__gte: str
        :param data__dps: data__dps
        :type data__dps: str
        :param data__crith__lt: data__crith__lt
        :type data__crith__lt: str
        :param data__crith__gt: data__crith__gt
        :type data__crith__gt: str
        :param data__crith__lte: data__crith__lte
        :type data__crith__lte: str
        :param data__crith__gte: data__crith__gte
        :type data__crith__gte: str
        :param data__crith: data__crith
        :type data__crith: str
        :param data__heal_crith__lt: data__heal_crith__lt
        :type data__heal_crith__lt: str
        :param data__heal_crith__gt: data__heal_crith__gt
        :type data__heal_crith__gt: str
        :param data__heal_crith__lte: data__heal_crith__lte
        :type data__heal_crith__lte: str
        :param data__heal_crith__gte: data__heal_crith__gte
        :type data__heal_crith__gte: str
        :param data__heal_crith: data__heal_crith
        :type data__heal_crith: str
        :param data__start_time: data__start_time
        :type data__start_time: str
        :param data__total_time: data__total_time
        :type data__total_time: str
        :param data__flanks__lt: data__flanks__lt
        :type data__flanks__lt: str
        :param data__flanks__gt: data__flanks__gt
        :type data__flanks__gt: str
        :param data__flanks__lte: data__flanks__lte
        :type data__flanks__lte: str
        :param data__flanks__gte: data__flanks__gte
        :type data__flanks__gte: str
        :param data__flanks: data__flanks
        :type data__flanks: str
        :param data__misses__lt: data__misses__lt
        :type data__misses__lt: str
        :param data__misses__gt: data__misses__gt
        :type data__misses__gt: str
        :param data__misses__lte: data__misses__lte
        :type data__misses__lte: str
        :param data__misses__gte: data__misses__gte
        :type data__misses__gte: str
        :param data__misses: data__misses
        :type data__misses: str
        :param data__kills__lt: data__kills__lt
        :type data__kills__lt: str
        :param data__kills__gt: data__kills__gt
        :type data__kills__gt: str
        :param data__kills__lte: data__kills__lte
        :type data__kills__lte: str
        :param data__kills__gte: data__kills__gte
        :type data__kills__gte: str
        :param data__kills: data__kills
        :type data__kills: str
        :param data__runtime: data__runtime
        :type data__runtime: str
        :param data__end_time: data__end_time
        :type data__end_time: str
        :param data__accuracy__lt: data__accuracy__lt
        :type data__accuracy__lt: str
        :param data__accuracy__gt: data__accuracy__gt
        :type data__accuracy__gt: str
        :param data__accuracy__lte: data__accuracy__lte
        :type data__accuracy__lte: str
        :param data__accuracy__gte: data__accuracy__gte
        :type data__accuracy__gte: str
        :param data__accuracy: data__accuracy
        :type data__accuracy: str
        :param data__resist__lt: data__resist__lt
        :type data__resist__lt: str
        :param data__resist__gt: data__resist__gt
        :type data__resist__gt: str
        :param data__resist__lte: data__resist__lte
        :type data__resist__lte: str
        :param data__resist__gte: data__resist__gte
        :type data__resist__gte: str
        :param data__resist: data__resist
        :type data__resist: str
        :param data__hull_attacks__lt: data__hull_attacks__lt
        :type data__hull_attacks__lt: str
        :param data__hull_attacks__gt: data__hull_attacks__gt
        :type data__hull_attacks__gt: str
        :param data__hull_attacks__lte: data__hull_attacks__lte
        :type data__hull_attacks__lte: str
        :param data__hull_attacks__gte: data__hull_attacks__gte
        :type data__hull_attacks__gte: str
        :param data__hull_attacks: data__hull_attacks
        :type data__hull_attacks: str
        :param data__final_resist__lt: data__final_resist__lt
        :type data__final_resist__lt: str
        :param data__final_resist__gt: data__final_resist__gt
        :type data__final_resist__gt: str
        :param data__final_resist__lte: data__final_resist__lte
        :type data__final_resist__lte: str
        :param data__final_resist__gte: data__final_resist__gte
        :type data__final_resist__gte: str
        :param data__final_resist: data__final_resist
        :type data__final_resist: str
        :param data__percent_attacks__lt: data__percent_attacks__lt
        :type data__percent_attacks__lt: str
        :param data__percent_attacks__gt: data__percent_attacks__gt
        :type data__percent_attacks__gt: str
        :param data__percent_attacks__lte: data__percent_attacks__lte
        :type data__percent_attacks__lte: str
        :param data__percent_attacks__gte: data__percent_attacks__gte
        :type data__percent_attacks__gte: str
        :param data__percent_attacks: data__percent_attacks
        :type data__percent_attacks: str
        :param data__percent_damage__lt: data__percent_damage__lt
        :type data__percent_damage__lt: str
        :param data__percent_damage__gt: data__percent_damage__gt
        :type data__percent_damage__gt: str
        :param data__percent_damage__lte: data__percent_damage__lte
        :type data__percent_damage__lte: str
        :param data__percent_damage__gte: data__percent_damage__gte
        :type data__percent_damage__gte: str
        :param data__percent_damage: data__percent_damage
        :type data__percent_damage: str
        :param data__percent_damage_taken__lt: data__percent_damage_taken__lt
        :type data__percent_damage_taken__lt: str
        :param data__percent_damage_taken__gt: data__percent_damage_taken__gt
        :type data__percent_damage_taken__gt: str
        :param data__percent_damage_taken__lte: data__percent_damage_taken__lte
        :type data__percent_damage_taken__lte: str
        :param data__percent_damage_taken__gte: data__percent_damage_taken__gte
        :type data__percent_damage_taken__gte: str
        :param data__percent_damage_taken: data__percent_damage_taken
        :type data__percent_damage_taken: str
        :param data__percent_healed__lt: data__percent_healed__lt
        :type data__percent_healed__lt: str
        :param data__percent_healed__gt: data__percent_healed__gt
        :type data__percent_healed__gt: str
        :param data__percent_healed__lte: data__percent_healed__lte
        :type data__percent_healed__lte: str
        :param data__percent_healed__gte: data__percent_healed__gte
        :type data__percent_healed__gte: str
        :param data__percent_healed: data__percent_healed
        :type data__percent_healed: str
        :param data__attacks_per_minute__lt: data__attacks_per_minute__lt
        :type data__attacks_per_minute__lt: str
        :param data__attacks_per_minute__gt: data__attacks_per_minute__gt
        :type data__attacks_per_minute__gt: str
        :param data__attacks_per_minute__lte: data__attacks_per_minute__lte
        :type data__attacks_per_minute__lte: str
        :param data__attacks_per_minute__gte: data__attacks_per_minute__gte
        :type data__attacks_per_minute__gte: str
        :param data__attacks_per_minute: data__attacks_per_minute
        :type data__attacks_per_minute: str
        :param data__hps__lt: data__hps__lt
        :type data__hps__lt: str
        :param data__hps__gt: data__hps__gt
        :type data__hps__gt: str
        :param data__hps__lte: data__hps__lte
        :type data__hps__lte: str
        :param data__hps__gte: data__hps__gte
        :type data__hps__gte: str
        :param data__hps: data__hps
        :type data__hps: str
        :param ordering: Which field to use when ordering the results.
        :type ordering: str
        :param page: A page number within the paginated result set.
        :type page: int
        :param page_size: Number of results to return per page.
        :type page_size: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(LadderEntriesList200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'player',
            'ladder',
            'ladder__name',
            'ladder__difficulty',
            'data__name',
            'data__is_player',
            'data__total_damage__lt',
            'data__total_damage__gt',
            'data__total_damage__lte',
            'data__total_damage__gte',
            'data__total_damage',
            'data__total_attacks__lt',
            'data__total_attacks__gt',
            'data__total_attacks__lte',
            'data__total_attacks__gte',
            'data__total_attacks',
            'data__total_hull_damage__lt',
            'data__total_hull_damage__gt',
            'data__total_hull_damage__lte',
            'data__total_hull_damage__gte',
            'data__total_hull_damage',
            'data__total_shield_damage__lt',
            'data__total_shield_damage__gt',
            'data__total_shield_damage__lte',
            'data__total_shield_damage__gte',
            'data__total_shield_damage',
            'data__total_heal_instances__lt',
            'data__total_heal_instances__gt',
            'data__total_heal_instances__lte',
            'data__total_heal_instances__gte',
            'data__total_heal_instances',
            'data__total_crits__lt',
            'data__total_crits__gt',
            'data__total_crits__lte',
            'data__total_crits__gte',
            'data__total_crits',
            'data__total_heal_crits__lt',
            'data__total_heal_crits__gt',
            'data__total_heal_crits__lte',
            'data__total_heal_crits__gte',
            'data__total_heal_crits',
            'data__total_heals__lt',
            'data__total_heals__gt',
            'data__total_heals__lte',
            'data__total_heals__gte',
            'data__total_heals',
            'data__total_damage_taken__lt',
            'data__total_damage_taken__gt',
            'data__total_damage_taken__lte',
            'data__total_damage_taken__gte',
            'data__total_damage_taken',
            'data__total_attacks_taken__lt',
            'data__total_attacks_taken__gt',
            'data__total_attacks_taken__lte',
            'data__total_attacks_taken__gte',
            'data__total_attacks_taken',
            'data__deaths__lt',
            'data__deaths__gt',
            'data__deaths__lte',
            'data__deaths__gte',
            'data__deaths',
            'data__max_one_hit__lt',
            'data__max_one_hit__gt',
            'data__max_one_hit__lte',
            'data__max_one_hit__gte',
            'data__max_one_hit',
            'data__max_one_hit_weapon',
            'data__max_one_heal__lt',
            'data__max_one_heal__gt',
            'data__max_one_heal__lte',
            'data__max_one_heal__gte',
            'data__max_one_heal',
            'data__max_one_heal_weapon',
            'data__dps__lt',
            'data__dps__gt',
            'data__dps__lte',
            'data__dps__gte',
            'data__dps',
            'data__crith__lt',
            'data__crith__gt',
            'data__crith__lte',
            'data__crith__gte',
            'data__crith',
            'data__heal_crith__lt',
            'data__heal_crith__gt',
            'data__heal_crith__lte',
            'data__heal_crith__gte',
            'data__heal_crith',
            'data__start_time',
            'data__total_time',
            'data__flanks__lt',
            'data__flanks__gt',
            'data__flanks__lte',
            'data__flanks__gte',
            'data__flanks',
            'data__misses__lt',
            'data__misses__gt',
            'data__misses__lte',
            'data__misses__gte',
            'data__misses',
            'data__kills__lt',
            'data__kills__gt',
            'data__kills__lte',
            'data__kills__gte',
            'data__kills',
            'data__runtime',
            'data__end_time',
            'data__accuracy__lt',
            'data__accuracy__gt',
            'data__accuracy__lte',
            'data__accuracy__gte',
            'data__accuracy',
            'data__resist__lt',
            'data__resist__gt',
            'data__resist__lte',
            'data__resist__gte',
            'data__resist',
            'data__hull_attacks__lt',
            'data__hull_attacks__gt',
            'data__hull_attacks__lte',
            'data__hull_attacks__gte',
            'data__hull_attacks',
            'data__final_resist__lt',
            'data__final_resist__gt',
            'data__final_resist__lte',
            'data__final_resist__gte',
            'data__final_resist',
            'data__percent_attacks__lt',
            'data__percent_attacks__gt',
            'data__percent_attacks__lte',
            'data__percent_attacks__gte',
            'data__percent_attacks',
            'data__percent_damage__lt',
            'data__percent_damage__gt',
            'data__percent_damage__lte',
            'data__percent_damage__gte',
            'data__percent_damage',
            'data__percent_damage_taken__lt',
            'data__percent_damage_taken__gt',
            'data__percent_damage_taken__lte',
            'data__percent_damage_taken__gte',
            'data__percent_damage_taken',
            'data__percent_healed__lt',
            'data__percent_healed__gt',
            'data__percent_healed__lte',
            'data__percent_healed__gte',
            'data__percent_healed',
            'data__attacks_per_minute__lt',
            'data__attacks_per_minute__gt',
            'data__attacks_per_minute__lte',
            'data__attacks_per_minute__gte',
            'data__attacks_per_minute',
            'data__hps__lt',
            'data__hps__gt',
            'data__hps__lte',
            'data__hps__gte',
            'data__hps',
            'ordering',
            'page',
            'page_size'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ladder_entries_list" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('player') is not None:  # noqa: E501
            _query_params.append(('player', _params['player']))

        if _params.get('ladder') is not None:  # noqa: E501
            _query_params.append(('ladder', _params['ladder']))

        if _params.get('ladder__name') is not None:  # noqa: E501
            _query_params.append(('ladder__name', _params['ladder__name']))

        if _params.get('ladder__difficulty') is not None:  # noqa: E501
            _query_params.append(('ladder__difficulty', _params['ladder__difficulty']))

        if _params.get('data__name') is not None:  # noqa: E501
            _query_params.append(('data__name', _params['data__name']))

        if _params.get('data__is_player') is not None:  # noqa: E501
            _query_params.append(('data__is_player', _params['data__is_player']))

        if _params.get('data__total_damage__lt') is not None:  # noqa: E501
            _query_params.append(('data__total_damage__lt', _params['data__total_damage__lt']))

        if _params.get('data__total_damage__gt') is not None:  # noqa: E501
            _query_params.append(('data__total_damage__gt', _params['data__total_damage__gt']))

        if _params.get('data__total_damage__lte') is not None:  # noqa: E501
            _query_params.append(('data__total_damage__lte', _params['data__total_damage__lte']))

        if _params.get('data__total_damage__gte') is not None:  # noqa: E501
            _query_params.append(('data__total_damage__gte', _params['data__total_damage__gte']))

        if _params.get('data__total_damage') is not None:  # noqa: E501
            _query_params.append(('data__total_damage', _params['data__total_damage']))

        if _params.get('data__total_attacks__lt') is not None:  # noqa: E501
            _query_params.append(('data__total_attacks__lt', _params['data__total_attacks__lt']))

        if _params.get('data__total_attacks__gt') is not None:  # noqa: E501
            _query_params.append(('data__total_attacks__gt', _params['data__total_attacks__gt']))

        if _params.get('data__total_attacks__lte') is not None:  # noqa: E501
            _query_params.append(('data__total_attacks__lte', _params['data__total_attacks__lte']))

        if _params.get('data__total_attacks__gte') is not None:  # noqa: E501
            _query_params.append(('data__total_attacks__gte', _params['data__total_attacks__gte']))

        if _params.get('data__total_attacks') is not None:  # noqa: E501
            _query_params.append(('data__total_attacks', _params['data__total_attacks']))

        if _params.get('data__total_hull_damage__lt') is not None:  # noqa: E501
            _query_params.append(('data__total_hull_damage__lt', _params['data__total_hull_damage__lt']))

        if _params.get('data__total_hull_damage__gt') is not None:  # noqa: E501
            _query_params.append(('data__total_hull_damage__gt', _params['data__total_hull_damage__gt']))

        if _params.get('data__total_hull_damage__lte') is not None:  # noqa: E501
            _query_params.append(('data__total_hull_damage__lte', _params['data__total_hull_damage__lte']))

        if _params.get('data__total_hull_damage__gte') is not None:  # noqa: E501
            _query_params.append(('data__total_hull_damage__gte', _params['data__total_hull_damage__gte']))

        if _params.get('data__total_hull_damage') is not None:  # noqa: E501
            _query_params.append(('data__total_hull_damage', _params['data__total_hull_damage']))

        if _params.get('data__total_shield_damage__lt') is not None:  # noqa: E501
            _query_params.append(('data__total_shield_damage__lt', _params['data__total_shield_damage__lt']))

        if _params.get('data__total_shield_damage__gt') is not None:  # noqa: E501
            _query_params.append(('data__total_shield_damage__gt', _params['data__total_shield_damage__gt']))

        if _params.get('data__total_shield_damage__lte') is not None:  # noqa: E501
            _query_params.append(('data__total_shield_damage__lte', _params['data__total_shield_damage__lte']))

        if _params.get('data__total_shield_damage__gte') is not None:  # noqa: E501
            _query_params.append(('data__total_shield_damage__gte', _params['data__total_shield_damage__gte']))

        if _params.get('data__total_shield_damage') is not None:  # noqa: E501
            _query_params.append(('data__total_shield_damage', _params['data__total_shield_damage']))

        if _params.get('data__total_heal_instances__lt') is not None:  # noqa: E501
            _query_params.append(('data__total_heal_instances__lt', _params['data__total_heal_instances__lt']))

        if _params.get('data__total_heal_instances__gt') is not None:  # noqa: E501
            _query_params.append(('data__total_heal_instances__gt', _params['data__total_heal_instances__gt']))

        if _params.get('data__total_heal_instances__lte') is not None:  # noqa: E501
            _query_params.append(('data__total_heal_instances__lte', _params['data__total_heal_instances__lte']))

        if _params.get('data__total_heal_instances__gte') is not None:  # noqa: E501
            _query_params.append(('data__total_heal_instances__gte', _params['data__total_heal_instances__gte']))

        if _params.get('data__total_heal_instances') is not None:  # noqa: E501
            _query_params.append(('data__total_heal_instances', _params['data__total_heal_instances']))

        if _params.get('data__total_crits__lt') is not None:  # noqa: E501
            _query_params.append(('data__total_crits__lt', _params['data__total_crits__lt']))

        if _params.get('data__total_crits__gt') is not None:  # noqa: E501
            _query_params.append(('data__total_crits__gt', _params['data__total_crits__gt']))

        if _params.get('data__total_crits__lte') is not None:  # noqa: E501
            _query_params.append(('data__total_crits__lte', _params['data__total_crits__lte']))

        if _params.get('data__total_crits__gte') is not None:  # noqa: E501
            _query_params.append(('data__total_crits__gte', _params['data__total_crits__gte']))

        if _params.get('data__total_crits') is not None:  # noqa: E501
            _query_params.append(('data__total_crits', _params['data__total_crits']))

        if _params.get('data__total_heal_crits__lt') is not None:  # noqa: E501
            _query_params.append(('data__total_heal_crits__lt', _params['data__total_heal_crits__lt']))

        if _params.get('data__total_heal_crits__gt') is not None:  # noqa: E501
            _query_params.append(('data__total_heal_crits__gt', _params['data__total_heal_crits__gt']))

        if _params.get('data__total_heal_crits__lte') is not None:  # noqa: E501
            _query_params.append(('data__total_heal_crits__lte', _params['data__total_heal_crits__lte']))

        if _params.get('data__total_heal_crits__gte') is not None:  # noqa: E501
            _query_params.append(('data__total_heal_crits__gte', _params['data__total_heal_crits__gte']))

        if _params.get('data__total_heal_crits') is not None:  # noqa: E501
            _query_params.append(('data__total_heal_crits', _params['data__total_heal_crits']))

        if _params.get('data__total_heals__lt') is not None:  # noqa: E501
            _query_params.append(('data__total_heals__lt', _params['data__total_heals__lt']))

        if _params.get('data__total_heals__gt') is not None:  # noqa: E501
            _query_params.append(('data__total_heals__gt', _params['data__total_heals__gt']))

        if _params.get('data__total_heals__lte') is not None:  # noqa: E501
            _query_params.append(('data__total_heals__lte', _params['data__total_heals__lte']))

        if _params.get('data__total_heals__gte') is not None:  # noqa: E501
            _query_params.append(('data__total_heals__gte', _params['data__total_heals__gte']))

        if _params.get('data__total_heals') is not None:  # noqa: E501
            _query_params.append(('data__total_heals', _params['data__total_heals']))

        if _params.get('data__total_damage_taken__lt') is not None:  # noqa: E501
            _query_params.append(('data__total_damage_taken__lt', _params['data__total_damage_taken__lt']))

        if _params.get('data__total_damage_taken__gt') is not None:  # noqa: E501
            _query_params.append(('data__total_damage_taken__gt', _params['data__total_damage_taken__gt']))

        if _params.get('data__total_damage_taken__lte') is not None:  # noqa: E501
            _query_params.append(('data__total_damage_taken__lte', _params['data__total_damage_taken__lte']))

        if _params.get('data__total_damage_taken__gte') is not None:  # noqa: E501
            _query_params.append(('data__total_damage_taken__gte', _params['data__total_damage_taken__gte']))

        if _params.get('data__total_damage_taken') is not None:  # noqa: E501
            _query_params.append(('data__total_damage_taken', _params['data__total_damage_taken']))

        if _params.get('data__total_attacks_taken__lt') is not None:  # noqa: E501
            _query_params.append(('data__total_attacks_taken__lt', _params['data__total_attacks_taken__lt']))

        if _params.get('data__total_attacks_taken__gt') is not None:  # noqa: E501
            _query_params.append(('data__total_attacks_taken__gt', _params['data__total_attacks_taken__gt']))

        if _params.get('data__total_attacks_taken__lte') is not None:  # noqa: E501
            _query_params.append(('data__total_attacks_taken__lte', _params['data__total_attacks_taken__lte']))

        if _params.get('data__total_attacks_taken__gte') is not None:  # noqa: E501
            _query_params.append(('data__total_attacks_taken__gte', _params['data__total_attacks_taken__gte']))

        if _params.get('data__total_attacks_taken') is not None:  # noqa: E501
            _query_params.append(('data__total_attacks_taken', _params['data__total_attacks_taken']))

        if _params.get('data__deaths__lt') is not None:  # noqa: E501
            _query_params.append(('data__deaths__lt', _params['data__deaths__lt']))

        if _params.get('data__deaths__gt') is not None:  # noqa: E501
            _query_params.append(('data__deaths__gt', _params['data__deaths__gt']))

        if _params.get('data__deaths__lte') is not None:  # noqa: E501
            _query_params.append(('data__deaths__lte', _params['data__deaths__lte']))

        if _params.get('data__deaths__gte') is not None:  # noqa: E501
            _query_params.append(('data__deaths__gte', _params['data__deaths__gte']))

        if _params.get('data__deaths') is not None:  # noqa: E501
            _query_params.append(('data__deaths', _params['data__deaths']))

        if _params.get('data__max_one_hit__lt') is not None:  # noqa: E501
            _query_params.append(('data__max_one_hit__lt', _params['data__max_one_hit__lt']))

        if _params.get('data__max_one_hit__gt') is not None:  # noqa: E501
            _query_params.append(('data__max_one_hit__gt', _params['data__max_one_hit__gt']))

        if _params.get('data__max_one_hit__lte') is not None:  # noqa: E501
            _query_params.append(('data__max_one_hit__lte', _params['data__max_one_hit__lte']))

        if _params.get('data__max_one_hit__gte') is not None:  # noqa: E501
            _query_params.append(('data__max_one_hit__gte', _params['data__max_one_hit__gte']))

        if _params.get('data__max_one_hit') is not None:  # noqa: E501
            _query_params.append(('data__max_one_hit', _params['data__max_one_hit']))

        if _params.get('data__max_one_hit_weapon') is not None:  # noqa: E501
            _query_params.append(('data__max_one_hit_weapon', _params['data__max_one_hit_weapon']))

        if _params.get('data__max_one_heal__lt') is not None:  # noqa: E501
            _query_params.append(('data__max_one_heal__lt', _params['data__max_one_heal__lt']))

        if _params.get('data__max_one_heal__gt') is not None:  # noqa: E501
            _query_params.append(('data__max_one_heal__gt', _params['data__max_one_heal__gt']))

        if _params.get('data__max_one_heal__lte') is not None:  # noqa: E501
            _query_params.append(('data__max_one_heal__lte', _params['data__max_one_heal__lte']))

        if _params.get('data__max_one_heal__gte') is not None:  # noqa: E501
            _query_params.append(('data__max_one_heal__gte', _params['data__max_one_heal__gte']))

        if _params.get('data__max_one_heal') is not None:  # noqa: E501
            _query_params.append(('data__max_one_heal', _params['data__max_one_heal']))

        if _params.get('data__max_one_heal_weapon') is not None:  # noqa: E501
            _query_params.append(('data__max_one_heal_weapon', _params['data__max_one_heal_weapon']))

        if _params.get('data__dps__lt') is not None:  # noqa: E501
            _query_params.append(('data__dps__lt', _params['data__dps__lt']))

        if _params.get('data__dps__gt') is not None:  # noqa: E501
            _query_params.append(('data__dps__gt', _params['data__dps__gt']))

        if _params.get('data__dps__lte') is not None:  # noqa: E501
            _query_params.append(('data__dps__lte', _params['data__dps__lte']))

        if _params.get('data__dps__gte') is not None:  # noqa: E501
            _query_params.append(('data__dps__gte', _params['data__dps__gte']))

        if _params.get('data__dps') is not None:  # noqa: E501
            _query_params.append(('data__dps', _params['data__dps']))

        if _params.get('data__crith__lt') is not None:  # noqa: E501
            _query_params.append(('data__crith__lt', _params['data__crith__lt']))

        if _params.get('data__crith__gt') is not None:  # noqa: E501
            _query_params.append(('data__crith__gt', _params['data__crith__gt']))

        if _params.get('data__crith__lte') is not None:  # noqa: E501
            _query_params.append(('data__crith__lte', _params['data__crith__lte']))

        if _params.get('data__crith__gte') is not None:  # noqa: E501
            _query_params.append(('data__crith__gte', _params['data__crith__gte']))

        if _params.get('data__crith') is not None:  # noqa: E501
            _query_params.append(('data__crith', _params['data__crith']))

        if _params.get('data__heal_crith__lt') is not None:  # noqa: E501
            _query_params.append(('data__heal_crith__lt', _params['data__heal_crith__lt']))

        if _params.get('data__heal_crith__gt') is not None:  # noqa: E501
            _query_params.append(('data__heal_crith__gt', _params['data__heal_crith__gt']))

        if _params.get('data__heal_crith__lte') is not None:  # noqa: E501
            _query_params.append(('data__heal_crith__lte', _params['data__heal_crith__lte']))

        if _params.get('data__heal_crith__gte') is not None:  # noqa: E501
            _query_params.append(('data__heal_crith__gte', _params['data__heal_crith__gte']))

        if _params.get('data__heal_crith') is not None:  # noqa: E501
            _query_params.append(('data__heal_crith', _params['data__heal_crith']))

        if _params.get('data__start_time') is not None:  # noqa: E501
            _query_params.append(('data__start_time', _params['data__start_time']))

        if _params.get('data__total_time') is not None:  # noqa: E501
            _query_params.append(('data__total_time', _params['data__total_time']))

        if _params.get('data__flanks__lt') is not None:  # noqa: E501
            _query_params.append(('data__flanks__lt', _params['data__flanks__lt']))

        if _params.get('data__flanks__gt') is not None:  # noqa: E501
            _query_params.append(('data__flanks__gt', _params['data__flanks__gt']))

        if _params.get('data__flanks__lte') is not None:  # noqa: E501
            _query_params.append(('data__flanks__lte', _params['data__flanks__lte']))

        if _params.get('data__flanks__gte') is not None:  # noqa: E501
            _query_params.append(('data__flanks__gte', _params['data__flanks__gte']))

        if _params.get('data__flanks') is not None:  # noqa: E501
            _query_params.append(('data__flanks', _params['data__flanks']))

        if _params.get('data__misses__lt') is not None:  # noqa: E501
            _query_params.append(('data__misses__lt', _params['data__misses__lt']))

        if _params.get('data__misses__gt') is not None:  # noqa: E501
            _query_params.append(('data__misses__gt', _params['data__misses__gt']))

        if _params.get('data__misses__lte') is not None:  # noqa: E501
            _query_params.append(('data__misses__lte', _params['data__misses__lte']))

        if _params.get('data__misses__gte') is not None:  # noqa: E501
            _query_params.append(('data__misses__gte', _params['data__misses__gte']))

        if _params.get('data__misses') is not None:  # noqa: E501
            _query_params.append(('data__misses', _params['data__misses']))

        if _params.get('data__kills__lt') is not None:  # noqa: E501
            _query_params.append(('data__kills__lt', _params['data__kills__lt']))

        if _params.get('data__kills__gt') is not None:  # noqa: E501
            _query_params.append(('data__kills__gt', _params['data__kills__gt']))

        if _params.get('data__kills__lte') is not None:  # noqa: E501
            _query_params.append(('data__kills__lte', _params['data__kills__lte']))

        if _params.get('data__kills__gte') is not None:  # noqa: E501
            _query_params.append(('data__kills__gte', _params['data__kills__gte']))

        if _params.get('data__kills') is not None:  # noqa: E501
            _query_params.append(('data__kills', _params['data__kills']))

        if _params.get('data__runtime') is not None:  # noqa: E501
            _query_params.append(('data__runtime', _params['data__runtime']))

        if _params.get('data__end_time') is not None:  # noqa: E501
            _query_params.append(('data__end_time', _params['data__end_time']))

        if _params.get('data__accuracy__lt') is not None:  # noqa: E501
            _query_params.append(('data__accuracy__lt', _params['data__accuracy__lt']))

        if _params.get('data__accuracy__gt') is not None:  # noqa: E501
            _query_params.append(('data__accuracy__gt', _params['data__accuracy__gt']))

        if _params.get('data__accuracy__lte') is not None:  # noqa: E501
            _query_params.append(('data__accuracy__lte', _params['data__accuracy__lte']))

        if _params.get('data__accuracy__gte') is not None:  # noqa: E501
            _query_params.append(('data__accuracy__gte', _params['data__accuracy__gte']))

        if _params.get('data__accuracy') is not None:  # noqa: E501
            _query_params.append(('data__accuracy', _params['data__accuracy']))

        if _params.get('data__resist__lt') is not None:  # noqa: E501
            _query_params.append(('data__resist__lt', _params['data__resist__lt']))

        if _params.get('data__resist__gt') is not None:  # noqa: E501
            _query_params.append(('data__resist__gt', _params['data__resist__gt']))

        if _params.get('data__resist__lte') is not None:  # noqa: E501
            _query_params.append(('data__resist__lte', _params['data__resist__lte']))

        if _params.get('data__resist__gte') is not None:  # noqa: E501
            _query_params.append(('data__resist__gte', _params['data__resist__gte']))

        if _params.get('data__resist') is not None:  # noqa: E501
            _query_params.append(('data__resist', _params['data__resist']))

        if _params.get('data__hull_attacks__lt') is not None:  # noqa: E501
            _query_params.append(('data__hull_attacks__lt', _params['data__hull_attacks__lt']))

        if _params.get('data__hull_attacks__gt') is not None:  # noqa: E501
            _query_params.append(('data__hull_attacks__gt', _params['data__hull_attacks__gt']))

        if _params.get('data__hull_attacks__lte') is not None:  # noqa: E501
            _query_params.append(('data__hull_attacks__lte', _params['data__hull_attacks__lte']))

        if _params.get('data__hull_attacks__gte') is not None:  # noqa: E501
            _query_params.append(('data__hull_attacks__gte', _params['data__hull_attacks__gte']))

        if _params.get('data__hull_attacks') is not None:  # noqa: E501
            _query_params.append(('data__hull_attacks', _params['data__hull_attacks']))

        if _params.get('data__final_resist__lt') is not None:  # noqa: E501
            _query_params.append(('data__final_resist__lt', _params['data__final_resist__lt']))

        if _params.get('data__final_resist__gt') is not None:  # noqa: E501
            _query_params.append(('data__final_resist__gt', _params['data__final_resist__gt']))

        if _params.get('data__final_resist__lte') is not None:  # noqa: E501
            _query_params.append(('data__final_resist__lte', _params['data__final_resist__lte']))

        if _params.get('data__final_resist__gte') is not None:  # noqa: E501
            _query_params.append(('data__final_resist__gte', _params['data__final_resist__gte']))

        if _params.get('data__final_resist') is not None:  # noqa: E501
            _query_params.append(('data__final_resist', _params['data__final_resist']))

        if _params.get('data__percent_attacks__lt') is not None:  # noqa: E501
            _query_params.append(('data__percent_attacks__lt', _params['data__percent_attacks__lt']))

        if _params.get('data__percent_attacks__gt') is not None:  # noqa: E501
            _query_params.append(('data__percent_attacks__gt', _params['data__percent_attacks__gt']))

        if _params.get('data__percent_attacks__lte') is not None:  # noqa: E501
            _query_params.append(('data__percent_attacks__lte', _params['data__percent_attacks__lte']))

        if _params.get('data__percent_attacks__gte') is not None:  # noqa: E501
            _query_params.append(('data__percent_attacks__gte', _params['data__percent_attacks__gte']))

        if _params.get('data__percent_attacks') is not None:  # noqa: E501
            _query_params.append(('data__percent_attacks', _params['data__percent_attacks']))

        if _params.get('data__percent_damage__lt') is not None:  # noqa: E501
            _query_params.append(('data__percent_damage__lt', _params['data__percent_damage__lt']))

        if _params.get('data__percent_damage__gt') is not None:  # noqa: E501
            _query_params.append(('data__percent_damage__gt', _params['data__percent_damage__gt']))

        if _params.get('data__percent_damage__lte') is not None:  # noqa: E501
            _query_params.append(('data__percent_damage__lte', _params['data__percent_damage__lte']))

        if _params.get('data__percent_damage__gte') is not None:  # noqa: E501
            _query_params.append(('data__percent_damage__gte', _params['data__percent_damage__gte']))

        if _params.get('data__percent_damage') is not None:  # noqa: E501
            _query_params.append(('data__percent_damage', _params['data__percent_damage']))

        if _params.get('data__percent_damage_taken__lt') is not None:  # noqa: E501
            _query_params.append(('data__percent_damage_taken__lt', _params['data__percent_damage_taken__lt']))

        if _params.get('data__percent_damage_taken__gt') is not None:  # noqa: E501
            _query_params.append(('data__percent_damage_taken__gt', _params['data__percent_damage_taken__gt']))

        if _params.get('data__percent_damage_taken__lte') is not None:  # noqa: E501
            _query_params.append(('data__percent_damage_taken__lte', _params['data__percent_damage_taken__lte']))

        if _params.get('data__percent_damage_taken__gte') is not None:  # noqa: E501
            _query_params.append(('data__percent_damage_taken__gte', _params['data__percent_damage_taken__gte']))

        if _params.get('data__percent_damage_taken') is not None:  # noqa: E501
            _query_params.append(('data__percent_damage_taken', _params['data__percent_damage_taken']))

        if _params.get('data__percent_healed__lt') is not None:  # noqa: E501
            _query_params.append(('data__percent_healed__lt', _params['data__percent_healed__lt']))

        if _params.get('data__percent_healed__gt') is not None:  # noqa: E501
            _query_params.append(('data__percent_healed__gt', _params['data__percent_healed__gt']))

        if _params.get('data__percent_healed__lte') is not None:  # noqa: E501
            _query_params.append(('data__percent_healed__lte', _params['data__percent_healed__lte']))

        if _params.get('data__percent_healed__gte') is not None:  # noqa: E501
            _query_params.append(('data__percent_healed__gte', _params['data__percent_healed__gte']))

        if _params.get('data__percent_healed') is not None:  # noqa: E501
            _query_params.append(('data__percent_healed', _params['data__percent_healed']))

        if _params.get('data__attacks_per_minute__lt') is not None:  # noqa: E501
            _query_params.append(('data__attacks_per_minute__lt', _params['data__attacks_per_minute__lt']))

        if _params.get('data__attacks_per_minute__gt') is not None:  # noqa: E501
            _query_params.append(('data__attacks_per_minute__gt', _params['data__attacks_per_minute__gt']))

        if _params.get('data__attacks_per_minute__lte') is not None:  # noqa: E501
            _query_params.append(('data__attacks_per_minute__lte', _params['data__attacks_per_minute__lte']))

        if _params.get('data__attacks_per_minute__gte') is not None:  # noqa: E501
            _query_params.append(('data__attacks_per_minute__gte', _params['data__attacks_per_minute__gte']))

        if _params.get('data__attacks_per_minute') is not None:  # noqa: E501
            _query_params.append(('data__attacks_per_minute', _params['data__attacks_per_minute']))

        if _params.get('data__hps__lt') is not None:  # noqa: E501
            _query_params.append(('data__hps__lt', _params['data__hps__lt']))

        if _params.get('data__hps__gt') is not None:  # noqa: E501
            _query_params.append(('data__hps__gt', _params['data__hps__gt']))

        if _params.get('data__hps__lte') is not None:  # noqa: E501
            _query_params.append(('data__hps__lte', _params['data__hps__lte']))

        if _params.get('data__hps__gte') is not None:  # noqa: E501
            _query_params.append(('data__hps__gte', _params['data__hps__gte']))

        if _params.get('data__hps') is not None:  # noqa: E501
            _query_params.append(('data__hps', _params['data__hps']))

        if _params.get('ordering') is not None:  # noqa: E501
            _query_params.append(('ordering', _params['ordering']))

        if _params.get('page') is not None:  # noqa: E501
            _query_params.append(('page', _params['page']))

        if _params.get('page_size') is not None:  # noqa: E501
            _query_params.append(('page_size', _params['page_size']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['Basic']  # noqa: E501

        _response_types_map = {
            '200': "LadderEntriesList200Response",
        }

        return self.api_client.call_api(
            '/ladder-entries/', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def ladder_entries_read(self, id : Annotated[StrictInt, Field(..., description="A unique integer value identifying this ladder entry.")], **kwargs) -> LadderEntry:  # noqa: E501
        """ladder_entries_read  # noqa: E501

        LadderEntry API  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.ladder_entries_read(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this ladder entry. (required)
        :type id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: LadderEntry
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the ladder_entries_read_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.ladder_entries_read_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def ladder_entries_read_with_http_info(self, id : Annotated[StrictInt, Field(..., description="A unique integer value identifying this ladder entry.")], **kwargs) -> ApiResponse:  # noqa: E501
        """ladder_entries_read  # noqa: E501

        LadderEntry API  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.ladder_entries_read_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: A unique integer value identifying this ladder entry. (required)
        :type id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(LadderEntry, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ladder_entries_read" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['Basic']  # noqa: E501

        _response_types_map = {
            '200': "LadderEntry",
        }

        return self.api_client.call_api(
            '/ladder-entries/{id}/', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conlist
from OSCR_django_client.models.ladder_entry import LadderEntry

class LadderEntriesList200Response(BaseModel):
    """
    LadderEntriesList200Response
    """
    count: StrictInt = Field(...)
    next: Optional[StrictStr] = None
    previous: Optional[StrictStr] = None
    results: conlist(LadderEntry) = Field(...)
    __properties = ["count", "next", "previous", "results"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LadderEntriesList200Response:
        """Create an instance of LadderEntriesList200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in results (list)
        _items = []
        if self.results:
            for _item in self.results:
                if _item:
                    _items.append(_item.to_dict())
            _dict['results'] = _items
        # set to None if next (nullable) is None
        # and __fields_set__ contains the field
        if self.next is None and "next" in self.__fields_set__:
            _dict['next'] = None

        # set to None if previous (nullable) is None
        # and __fields_set__ contains the field
        if self.previous is None and "previous" in self.__fields_set__:
            _dict['previous'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LadderEntriesList200Response:
        """Create an instance of LadderEntriesList200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return LadderEntriesList200Response.parse_obj(obj)

        _obj = LadderEntriesList200Response.parse_obj({
            "count": obj.get("count"),
            "next": obj.get("next"),
            "previous": obj.get("previous"),
            "results": [LadderEntry.from_dict(_item) for _item in obj.get("results")] if obj.get("results") is not None else None
        })
        return _obj





# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, constr

class Ladder(BaseModel):
    """
    Ladder
    """
    id: Optional[StrictInt] = None
    name: constr(strict=True, min_length=1) = Field(...)
    difficulty: constr(strict=True, min_length=1) = Field(...)
    metric: constr(strict=True, min_length=1) = Field(...)
    __properties = ["id", "name", "difficulty", "metric"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Ladder:
        """Create an instance of Ladder from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "id",
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Ladder:
        """Create an instance of Ladder from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Ladder.parse_obj(obj)

        _obj = Ladder.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "difficulty": obj.get("difficulty"),
            "metric": obj.get("metric")
        })
        return _obj


